@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2007, 2020, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -155,7 +155,7 @@ public final class DataSourceWindowManager {
         synchronized (windowListeners) {
             List<DataSourceWindowListener> listeners = windowListeners.get(dataSource);
             if (listeners != null)
-                for (DataSourceWindowListener listener : new ArrayList<DataSourceWindowListener>(listeners))
+                for (DataSourceWindowListener listener : new ArrayList<>(listeners))
                     listener.windowOpened(dataSource);
         }
     }
@@ -164,7 +164,7 @@ public final class DataSourceWindowManager {
         synchronized (windowListeners) {
             List<DataSourceWindowListener> listeners = windowListeners.get(dataSource);
             if (listeners != null)
-                for (DataSourceWindowListener listener : new ArrayList<DataSourceWindowListener>(listeners))
+                for (DataSourceWindowListener listener : new ArrayList<>(listeners))
                     listener.windowClosed(dataSource);
         }
     }
