@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2017, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  * 
  * This code is free software; you can redistribute it and/or modify it
@@ -325,7 +325,7 @@ public class TruffleObjectsProvider<O extends TruffleObject, T extends TruffleTy
     
     public static Set<Instance> getDominatorRoots(List<Instance> searchInstances) {
         Set<Instance> dominators = new HashSet(searchInstances);
-        Set<Instance> removed = new HashSet();
+        Set<Instance> removed = new HashSet<>();
 
         for (Instance instance : searchInstances) {
             if (dominators.contains(instance)) {
