@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2017, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  * 
  * This code is free software; you can redistribute it and/or modify it
@@ -91,11 +91,11 @@ public class DynamicObject extends TruffleObject.InstanceBased {
     }
     
     public List<FieldValue> getReferences() {
-        List<FieldValue> dynObjRefs = new ArrayList();
+        List<FieldValue> dynObjRefs = new ArrayList<>();
 
         if (getShape() != null) {
             List<Value> refs = instance.getReferences();
-            Set<Instance> foundRefs = new HashSet();
+            Set<Instance> foundRefs = new HashSet<>();
 
             for (Value ref : refs) {
                 Instance instanceRef = ref.getDefiningInstance();
@@ -219,8 +219,8 @@ public class DynamicObject extends TruffleObject.InstanceBased {
         if (propertyMap == null) propertyMap = getValueofFields(instance, "shape", "propertyMap"); // NOI18N
         if (propertyMap != null) {
 //            properties = new ArrayList();
-            values = new ArrayList();
-            staticValues = new ArrayList();
+            values = new ArrayList<>();
+            staticValues = new ArrayList<>();
             boolean hasExtRef = hasField(instance.getJavaClass(), "extRef");    // NOI18N
             boolean hasShortNames = hasField(instance.getJavaClass(), "o0");    // NOI18N
 
@@ -286,7 +286,9 @@ public class DynamicObject extends TruffleObject.InstanceBased {
                 while (objTypeCls != null) {
                     JavaClass superObjType = objTypeCls.getSuperClass();
 
-                    if (superObjType == null || OBJECT_TYPE_FQN.equals(superObjType.getName())) {
+                    if (superObjType == null
+                       || OBJECT_TYPE_FQN.equals(superObjType.getName())
+                       || Object.class.getName().equals(superObjType.getName())) {
                         return objTypeCls;
                     }
                     objTypeCls = superObjType;
@@ -326,7 +328,7 @@ public class DynamicObject extends TruffleObject.InstanceBased {
     }
 
     private static List<Instance> getHashMapValues(Instance propertyMap) {
-        List<Instance> mapValues = new ArrayList();
+        List<Instance> mapValues = new ArrayList<>();
         Object val = propertyMap.getValueOfField("table");  // NOI18N
 
         if (val != null && val instanceof ObjectArrayInstance) {
@@ -346,7 +348,7 @@ public class DynamicObject extends TruffleObject.InstanceBased {
     }
 
     private static List<Instance> getConsListValues(Instance propertyMap) {
-        List<Instance> mapValues = new ArrayList();
+        List<Instance> mapValues = new ArrayList<>();
 
         for (Instance node = propertyMap; node != null; node = (Instance) node.getValueOfField("car")) {    // NOI18N
             Object value = node.getValueOfField("cdr"); // NOI18N
@@ -359,7 +361,7 @@ public class DynamicObject extends TruffleObject.InstanceBased {
     }
 
     private static List<Instance> getTrieValues(Instance propertyMap) {
-        List<Instance> mapValues = new ArrayList();
+        List<Instance> mapValues = new ArrayList<>();
         Object root = propertyMap.getValueOfField("root");  // NOI18N
 
         getNodeValues(root, mapValues);
@@ -687,7 +689,8 @@ public class DynamicObject extends TruffleObject.InstanceBased {
                 Instance actualLoc = (Instance) loc.getValueOfField("actualLocation");  // NOI18N
                 return getValueImpl(actualLoc, dynamicObject);
             }
-            if (className.contains("ObjectFieldLocation")) {    // NOI18N
+            if (className.contains("ObjectFieldLocation")               // NOI18N
+                || className.contains("ExtensionArrayLocation")) {      // NOI18N
                 String fName = getEnterpriseObjectFieldName(loc);
                 FieldValue ret = getInstanceFieldValue(dynamicObject, fName);
                 if (ret == null) {
@@ -732,33 +735,39 @@ public class DynamicObject extends TruffleObject.InstanceBased {
             }
             if (className.contains("IntArrayLocation")) {   // NOI18N
                 Integer index = (Integer) loc.getValueOfField("index"); // NOI18N
-                Instance actualLoc = (Instance) loc.getValueOfField("arrayLocation");   // NOI18N
-                ObjectFieldValue arrayVal = (ObjectFieldValue) getValueImpl(actualLoc, dynamicObject);
-                PrimitiveArrayInstance arr = (PrimitiveArrayInstance) arrayVal.getInstance();
+                PrimitiveArrayInstance arr = getPrimitiveArray(loc, dynamicObject);
                 return getFieldValue(dynamicObject, arr.getValues().get(index));
             }
             if (className.contains("DoubleArrayLocation")) {    // NOI18N
                 Integer index = (Integer) loc.getValueOfField("index"); // NOI18N
-                Instance actualLoc = (Instance) loc.getValueOfField("arrayLocation");   // NOI18N
-                ObjectFieldValue arrayVal = (ObjectFieldValue) getValueImpl(actualLoc, dynamicObject);
-                PrimitiveArrayInstance arr = (PrimitiveArrayInstance) arrayVal.getInstance();
+                PrimitiveArrayInstance arr = getPrimitiveArray(loc, dynamicObject);
                 return getFieldValue(dynamicObject, getDouble(getLong(arr, index)));
             }
             if (className.contains("LongArrayLocation")) {    // NOI18N
                 Integer index = (Integer) loc.getValueOfField("index"); // NOI18N
-                Instance actualLoc = (Instance) loc.getValueOfField("arrayLocation");   // NOI18N
-                ObjectFieldValue arrayVal = (ObjectFieldValue) getValueImpl(actualLoc, dynamicObject);
-                PrimitiveArrayInstance arr = (PrimitiveArrayInstance) arrayVal.getInstance();
+                PrimitiveArrayInstance arr = getPrimitiveArray(loc, dynamicObject);
                 return getFieldValue(dynamicObject, Long.toString(getLong(arr, index)));
             }
             return null;
         }
 
+        private PrimitiveArrayInstance getPrimitiveArray(Instance loc, Instance dynamicObject) {
+            Instance actualLoc = (Instance) loc.getValueOfField("arrayLocation");   // NOI18N
+            PrimitiveArrayInstance arr;
+            if (actualLoc == null) {
+                arr =  (PrimitiveArrayInstance) dynamicObject.getValueOfField("extVal");    // NOI18N
+            } else {
+                ObjectFieldValue arrayVal = (ObjectFieldValue) getValueImpl(actualLoc, dynamicObject);
+                arr = (PrimitiveArrayInstance) ((ObjectFieldValue)arrayVal).getInstance();
+            }
+            return arr;
+        }
+
         private Object getValueOfNextField(Instance dynamicObject, String fieldName) {
             int i = fieldName.length()-1;
             for (; i>=0 && Character.isDigit(fieldName.charAt(i)); i--);
             assert i < fieldName.length()-1 : "Invalid fname "+fieldName;
-            int fIndex = Integer.valueOf(fieldName.substring(++i));
+            int fIndex = Integer.parseInt(fieldName.substring(++i));
 
             return dynamicObject.getValueOfField(fieldName.substring(0,i)+(fIndex+1));
         }
