@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2017, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -55,6 +55,7 @@ class PythonObject extends TruffleObject.InstanceBased {
     static final String PYTHON_LIST_FQN = "com.oracle.graal.python.builtins.objects.list.PList"; // NOI18N
     static final String TREEMAP_ENTRY_FQN = "java.util.TreeMap$Entry";  // NOI18N
     static final String TREEMAP_FQN = "java.util.TreeMap";  // NOI18N
+    private static final String HASHING_STORAGE_FQN = "com.oracle.graal.python.builtins.objects.common.HashingStorage";     // NOI18N
 
     private final Instance instance;
     private final Instance storage;
@@ -90,7 +91,7 @@ class PythonObject extends TruffleObject.InstanceBased {
         array = (ObjectArrayInstance) values[5];
         map = (Instance) values[6];
         set = (Instance) values[7];
-        dictStorage = (Instance) values[8];
+        dictStorage = computeDict((Instance) values[8], storage);
     }
     
     private static Instance computeStorage(Instance storage, Instance pythonInstance) {
@@ -99,6 +100,14 @@ class PythonObject extends TruffleObject.InstanceBased {
         return null;
     }
     
+    private static Instance computeDict(Instance dict, Instance storage) {
+        if (dict != null) return dict;
+        if (isSubClassOf(storage, HASHING_STORAGE_FQN)) {
+            return storage;
+        }
+        return null;
+    }
+
     private static Instance computePythonClass(Instance pythonClass, Instance storedPythonClass, Instance initialPythonClass, Instance storage) {
         if (pythonClass != null) return pythonClass;
         if (storedPythonClass != null) return storedPythonClass;
@@ -183,7 +192,7 @@ class PythonObject extends TruffleObject.InstanceBased {
 
     List<FieldValue> getReferences() {
         List<Value> refs = instance.getReferences();
-        List<FieldValue> robjRefs = new ArrayList();
+        List<FieldValue> robjRefs = new ArrayList<>();
 
         for (Value ref : refs) {
             Instance defInstance = ref.getDefiningInstance();
@@ -387,7 +396,7 @@ class PythonObject extends TruffleObject.InstanceBased {
     }
 
     private List<FieldValue> getEntriesFromKeywords(ObjectArrayInstance keywords) {
-        List fields = new ArrayList();
+        List<FieldValue> fields = new ArrayList<>();
 
         for (Instance keyword : keywords.getValues()) {
             if (keyword != null) {
@@ -398,8 +407,13 @@ class PythonObject extends TruffleObject.InstanceBased {
     }
 
     private List<FieldValue> getEntriesFromEconomicMapStorage(boolean isSet, Instance economicMapStorage) {
-        List fields = new ArrayList();
-        Instance entries = (Instance) economicMapStorage.getValueOfField("entries"); // NOI18N
+        Instance entries;
+        List<FieldValue> fields = new ArrayList<>();
+        Instance economicMap = (Instance) economicMapStorage.getValueOfField("map"); // NOI18N
+        if (economicMap instanceof Instance) {
+            economicMapStorage = economicMap;
+        }
+        entries = (Instance) economicMapStorage.getValueOfField("entries"); // NOI18N
 
         if (entries instanceof ObjectArrayInstance) {
             ObjectArrayInstance entriesArr = (ObjectArrayInstance) entries;
@@ -414,14 +428,11 @@ class PythonObject extends TruffleObject.InstanceBased {
                     if (isSet) {
                         fields.add(new PythonEconomicEntryFieldValue(key));
                     } else {    // Map
-                        if (value != null) {
-                            if (value instanceof Instance) {
-                                Instance ival = ((Instance)value);
+                        if (value instanceof Instance) {
+                            Instance ival = ((Instance)value);
+                            if (ival.getJavaClass().getName().startsWith(mapClassName)) {
                                 Instance linkValue = (Instance) ival.getValueOfField("value"); // NOI18N
-
-                                if (linkValue != null && ival.getJavaClass().getName().startsWith(mapClassName)) {
-                                    value = linkValue;
-                                }
+                                if (linkValue != null) value = linkValue;
                             }
                         }
                         fields.add(new PythonEconomicEntryFieldValue(key, value));
@@ -433,7 +444,7 @@ class PythonObject extends TruffleObject.InstanceBased {
     }
 
     private List<FieldValue> getEntriesFromTreeMap(boolean isSet, Instance treeMap) {
-        List fields = new ArrayList();
+        List<FieldValue> fields = new ArrayList<>();
         Instance rootEntry = (Instance) treeMap.getValueOfField("root"); // NOI18N
 
         getEntries(isSet, rootEntry, fields);
@@ -636,12 +647,34 @@ class PythonObject extends TruffleObject.InstanceBased {
 
         @Override
         public Type getType() {
-            return new Type() {
-                @Override
-                public String getName() {
-                    return listType;
-                }
-            };
+            return new PFieldType(listType);
+        }
+    }
+
+    private static class PFieldType implements Type {
+
+        private final String name;
+
+        PFieldType(String n) {
+            name = n;
+        }
+
+        @Override
+        public String getName() {
+            return name;
+        }
+
+        @Override
+        public boolean equals(Object obj) {
+            if (obj instanceof PFieldType) {
+                return getName().equals(((PFieldType)obj).getName());
+            }
+            return false;
+        }
+
+        @Override
+        public int hashCode() {
+            return getName().hashCode();
         }
     }
 
