@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2017, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -97,7 +97,7 @@ class RObject extends TruffleObject.InstanceBased {
     private static Map<String,String> typeMap;
 
     static {
-        typeMap = new HashMap();
+        typeMap = new HashMap<>();
         for (int i=0; i<typeMaping.length; i+=2) {
             typeMap.put(typeMaping[i], typeMaping[i+1]);
         }
@@ -122,11 +122,11 @@ class RObject extends TruffleObject.InstanceBased {
     private String type;
 
 
-    public RObject(Instance instance) {
+    RObject(Instance instance) {
         this(null, instance);
     }
 
-    public RObject(String type, Instance instance) {
+    RObject(String type, Instance instance) {
         this.instance = instance;
         this.type = type;
 
@@ -336,7 +336,7 @@ class RObject extends TruffleObject.InstanceBased {
 
     List<FieldValue> getReferences() {
         List<Value> refs = instance.getReferences();
-        List<FieldValue> robjRefs = new ArrayList();
+        List<FieldValue> robjRefs = new ArrayList<>();
 
         for (Value ref : refs) {
             Instance defInstance = ref.getDefiningInstance();
@@ -515,7 +515,7 @@ class RObject extends TruffleObject.InstanceBased {
 
                 length = 0;
                 values = new ArrayList();
-                List<String> nameList = new ArrayList();
+                List<String> nameList = new ArrayList<>();
                 for (Instance cdr = pairListInstance;
                    cdr != null && cdr.getJavaClass().equals(pairListClass);
                    cdr = (Instance) cdr.getValueOfField("cdr")) { // NOI18N
@@ -701,7 +701,7 @@ class RObject extends TruffleObject.InstanceBased {
 
     private class RLogicalFieldValue extends RFieldValue {
 
-        public RLogicalFieldValue(int i) {
+        RLogicalFieldValue(int i) {
             super(i);
         }
 
@@ -726,7 +726,7 @@ class RObject extends TruffleObject.InstanceBased {
 
     private class RComplexFieldValue extends RFieldValue {
 
-        public RComplexFieldValue(int i) {
+        RComplexFieldValue(int i) {
             super(i);
         }
 
@@ -787,7 +787,7 @@ class RObject extends TruffleObject.InstanceBased {
         }
     }
     
-    private class FrameFieldValue implements ObjectFieldValue {
+    private static class FrameFieldValue implements ObjectFieldValue {
 
         final ObjectFieldValue frameValue;
         final Instance rObject;
@@ -876,12 +876,7 @@ class RObject extends TruffleObject.InstanceBased {
 
         @Override
         public Type getType() {
-            return new Type() {
-                @Override
-                public String getName() {
-                    return dataType;
-                }
-            };
+            return new RFieldType(dataType);
         }
     }
 
@@ -896,12 +891,34 @@ class RObject extends TruffleObject.InstanceBased {
 
         @Override
         public Type getType() {
-            return new Type() {
-                @Override
-                public String getName() {
-                    return name;
-                }
-            };
+            return new RFieldType(name);
+        }
+    }
+
+    private static class RFieldType implements Type {
+
+        private final String name;
+
+        RFieldType(String n) {
+            name = n;
+        }
+
+        @Override
+        public String getName() {
+            return name;
+        }
+
+        @Override
+        public boolean equals(Object obj) {
+            if (obj instanceof RFieldType) {
+                return getName().equals(((RFieldType)obj).getName());
+            }
+            return false;
+        }
+
+        @Override
+        public int hashCode() {
+            return getName().hashCode();
         }
     }
 }
