@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2018, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  * 
  * This code is free software; you can redistribute it and/or modify it
@@ -757,7 +757,7 @@ public class TruffleSummaryView extends HeapViewerFeature {
             }
             
             Set<Instance> rootInstances = TruffleObjectsProvider.getDominatorRoots(searchInstances);
-            List<O> rootObjects = new ArrayList();
+            List<O> rootObjects = new ArrayList<>();
             for (Instance root : rootInstances) rootObjects.add(language.createObject(root));
             
             return rootObjects;
