@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2018, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -24,17 +24,6 @@
  */
 package org.graalvm.visualvm.heapviewer.java.impl;
 
-import org.graalvm.visualvm.core.ui.components.SectionSeparator;
-import org.graalvm.visualvm.heapviewer.HeapContext;
-import org.graalvm.visualvm.heapviewer.java.JavaHeapFragment;
-import org.graalvm.visualvm.heapviewer.swing.LinkButton;
-import org.graalvm.visualvm.heapviewer.swing.Splitter;
-import org.graalvm.visualvm.heapviewer.ui.HeapView;
-import org.graalvm.visualvm.heapviewer.ui.HeapViewerActions;
-import org.graalvm.visualvm.heapviewer.ui.HeapViewerNodeAction;
-import org.graalvm.visualvm.heapviewer.ui.SummaryView;
-import org.graalvm.visualvm.uisupport.SeparatorLine;
-import org.graalvm.visualvm.uisupport.VerticalLayout;
 import java.awt.BorderLayout;
 import java.awt.Color;
 import java.awt.Dimension;
@@ -53,6 +42,7 @@ import java.util.List;
 import java.util.Map;
 import java.util.Properties;
 import java.util.Set;
+import java.util.SortedSet;
 import java.util.TreeSet;
 import javax.swing.BorderFactory;
 import javax.swing.JComponent;
@@ -67,6 +57,15 @@ import javax.swing.table.TableModel;
 import javax.swing.text.BadLocationException;
 import javax.swing.text.Caret;
 import javax.swing.text.JTextComponent;
+import org.graalvm.visualvm.core.ui.components.SectionSeparator;
+import org.graalvm.visualvm.heapviewer.HeapContext;
+import org.graalvm.visualvm.heapviewer.java.JavaHeapFragment;
+import org.graalvm.visualvm.heapviewer.swing.LinkButton;
+import org.graalvm.visualvm.heapviewer.swing.Splitter;
+import org.graalvm.visualvm.heapviewer.ui.HeapView;
+import org.graalvm.visualvm.heapviewer.ui.HeapViewerActions;
+import org.graalvm.visualvm.heapviewer.ui.HeapViewerNodeAction;
+import org.graalvm.visualvm.heapviewer.ui.SummaryView;
 import org.graalvm.visualvm.lib.jfluid.heap.Heap;
 import org.graalvm.visualvm.lib.jfluid.heap.HeapSummary;
 import org.graalvm.visualvm.lib.jfluid.heap.Instance;
@@ -78,6 +77,8 @@ import org.graalvm.visualvm.lib.ui.components.HTMLTextArea;
 import org.graalvm.visualvm.lib.ui.components.HTMLTextAreaSearchUtils;
 import org.graalvm.visualvm.lib.ui.components.ProfilerToolbar;
 import org.graalvm.visualvm.lib.ui.swing.renderer.LabelRenderer;
+import org.graalvm.visualvm.uisupport.SeparatorLine;
+import org.graalvm.visualvm.uisupport.VerticalLayout;
 import org.openide.util.Exceptions;
 import org.openide.util.NbBundle;
 import org.openide.util.lookup.ServiceProvider;
@@ -244,11 +245,16 @@ class JavaOverviewSummary extends HeapView {
 
             String home = sysprops.getProperty("java.home", Bundle.JavaOverviewSummary_NotAvailable()); // NOI18N
 
+            String name_ver = sysprops.getProperty("java.vm.version", ""); // NOI18N
             String version = sysprops.getProperty("java.version", Bundle.JavaOverviewSummary_NotAvailable()); // NOI18N
             if ("0".equals(version)) version = Bundle.JavaOverviewSummary_NotAvailable(); // NOI18N
+            else {
+                String relDate = sysprops.getProperty("java.version.date", "");         // NOI18N
+                if (!relDate.isEmpty()) version += " " + relDate;
+                if (name_ver.contains("LTS")) version += " LTS";           // NOI18N
+            }
 
             String name = sysprops.getProperty("java.vm.name", Bundle.JavaOverviewSummary_NotAvailable()); // NOI18N
-            String name_ver = sysprops.getProperty("java.vm.version", ""); // NOI18N
             String name_info = sysprops.getProperty("java.vm.info", ""); // NOI18N
             if (name_ver.isEmpty() || name_info.isEmpty()) {
                 if (name_ver.isEmpty()) name += " (" + name_info + ")"; // NOI18N
@@ -356,14 +362,13 @@ class JavaOverviewSummary extends HeapView {
     private String computeModules(Heap heap) {
         JavaClass resolvedModulesClass = heap.getJavaClassByName("java.lang.module.ResolvedModule"); // NOI18N
         if (resolvedModulesClass != null) {
-            List<String> resolvedModules = new ArrayList();
+            SortedSet<String> resolvedModules = new TreeSet(String.CASE_INSENSITIVE_ORDER);
             List<Instance> modules = resolvedModulesClass.getInstances();
 
             for (Instance module : modules) {
                 resolvedModules.add(DetailsSupport.getDetailsString(module));
             }
             if (resolvedModules.isEmpty()) return null;
-            resolvedModules.sort(String.CASE_INSENSITIVE_ORDER);
             return formatModules(resolvedModules);
         }
         return null;
@@ -413,7 +418,7 @@ class JavaOverviewSummary extends HeapView {
         return null;
     }
 
-    private String formatModules(List<String> data) {
+    private String formatModules(Collection<String> data) {
         boolean oddRow = false;
         Color oddRowBackground = UIUtils.getDarker(
                                  UIUtils.getProfilerResultsBackground());
@@ -512,7 +517,7 @@ class JavaOverviewSummary extends HeapView {
         long seconds = millis / 1000;
         String sSeconds = ((seconds < 10) ? "0" + seconds : "" + seconds); // NOI18N
 
-        if (sHours.length() == 0) {
+        if (sHours.isEmpty()) {
             return Bundle.JavaOverviewSummary_FORMAT_ms(sMinutes, sSeconds);
         } else {
             return Bundle.JavaOverviewSummary_FORMAT_hms(sHours, sMinutes, sSeconds);
