@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2018, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -24,6 +24,12 @@
  */
 package org.graalvm.visualvm.heapviewer.java.impl;
 
+import java.net.URL;
+import java.util.ArrayList;
+import java.util.Collection;
+import java.util.HashMap;
+import java.util.List;
+import java.util.Map;
 import org.graalvm.visualvm.heapviewer.HeapContext;
 import org.graalvm.visualvm.heapviewer.java.ClassNode;
 import org.graalvm.visualvm.heapviewer.java.InstanceNode;
@@ -33,12 +39,6 @@ import org.graalvm.visualvm.heapviewer.java.ThreadNode;
 import org.graalvm.visualvm.heapviewer.model.HeapViewerNode;
 import org.graalvm.visualvm.heapviewer.model.RootNode;
 import org.graalvm.visualvm.heapviewer.utils.HeapUtils;
-import java.net.URL;
-import java.util.ArrayList;
-import java.util.Collection;
-import java.util.HashMap;
-import java.util.List;
-import java.util.Map;
 import org.graalvm.visualvm.lib.jfluid.heap.GCRoot;
 import org.graalvm.visualvm.lib.jfluid.heap.Heap;
 import org.graalvm.visualvm.lib.jfluid.heap.Instance;
@@ -70,11 +70,20 @@ class JavaThreadsProvider {
     
     static String getThreadName(Instance instance) {
         String threadName = getThreadInstanceName(instance);
+        Long threadId = (Long)instance.getValueOfField("tid");    // NOI18N
         Boolean daemon = (Boolean)instance.getValueOfField("daemon"); // NOI18N
         Integer priority = (Integer)instance.getValueOfField("priority"); // NOI18N
-        Long threadId = (Long)instance.getValueOfField("tid");    // NOI18N
         Integer threadStatus = (Integer)instance.getValueOfField("threadStatus"); // NOI18N
 
+        if (daemon == null) {
+            Instance holder = (Instance)instance.getValueOfField("holder");  // NOI18N
+            if (holder != null) {
+                daemon = (Boolean)holder.getValueOfField("daemon"); // NOI18N
+                priority = (Integer)holder.getValueOfField("priority"); // NOI18N
+                threadStatus = (Integer)holder.getValueOfField("threadStatus"); // NOI18N
+            }
+        }
+
         String tName = "\"" + threadName + "\"" + (daemon.booleanValue() ? " daemon" : "") + " prio=" + priority; // NOI18N
         if (threadId != null) tName += " tid=" + threadId; // NOI18N
         if (threadStatus != null) tName += " " + toThreadState(threadStatus.intValue()); // NOI18N
@@ -198,6 +207,7 @@ class JavaThreadsProvider {
         JavaClass javaClassClass = heap.getJavaClassByName(Class.class.getName());
         // Use this to enable VisualVM color scheme for threads dumps:
         // sw.append("<pre style='color: #cc3300;'>"); // NOI18N
+        sb.append("<head><style>span.g {color: #666666;}</style></head>");
         sb.append("<pre>"); // NOI18N
         for (GCRoot root : roots) {
             if(root.getKind().equals(GCRoot.THREAD_OBJECT)) {
@@ -255,7 +265,7 @@ class JavaThreadsProvider {
                                             } else if (GCRoot.JNI_LOCAL.equals(local.getKind())) {
                                                 text = Bundle.JavaThreadsProvider_JniLocal();
                                             }
-                                            sb.append("       <span style=\"color: #666666\">" + text + ":</span> ").append(HeapUtils.instanceToHtml(localInstance, false, javaClassClass)).append("<br>"); // NOI18N
+                                            sb.append("       <span class=\"g\">" + text + ":</span> ").append(HeapUtils.instanceToHtml(localInstance, false, javaClassClass)).append("<br>"); // NOI18N
                                         } else {
                                             String text = "";
                                             if (GCRoot.JAVA_FRAME.equals(local.getKind())) {
@@ -263,7 +273,7 @@ class JavaThreadsProvider {
                                             } else if (GCRoot.JNI_LOCAL.equals(local.getKind())) {
                                                 text = Bundle.JavaThreadsProvider_UnknownJniLocal();
                                             }
-                                            sb.append("       <span style=\"color: #666666\">" + text + "</span><br>"); // NOI18N
+                                            sb.append("       <span class=\"g\">" + text + "</span><br>"); // NOI18N
                                         }
                                     }
                                 }
