@@ -1,44 +1,26 @@
 /*
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
+ * Copyright (c) 1997, 2021, Oracle and/or its affiliates. All rights reserved.
+ * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
- * Copyright 1997-2013 Oracle and/or its affiliates. All rights reserved.
- *
- * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
- * Other names may be trademarks of their respective owners.
- *
- * The contents of this file are subject to the terms of either the GNU
- * General Public License Version 2 only ("GPL") or the Common
- * Development and Distribution License("CDDL") (collectively, the
- * "License"). You may not use this file except in compliance with the
- * License. You can obtain a copy of the License at
- * http://www.netbeans.org/cddl-gplv2.html
- * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
- * specific language governing permissions and limitations under the
- * License.  When distributing the software, include this License Header
- * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
+ * This code is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License version 2 only, as
+ * published by the Free Software Foundation.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Oracle in the GPL Version 2 section of the License file that
- * accompanied this code. If applicable, add the following below the
- * License Header, with the fields enclosed by brackets [] replaced by
- * your own identifying information:
- * "Portions Copyrighted [year] [name of copyright owner]"
+ * by Oracle in the LICENSE file that accompanied this code.
  *
- * Contributor(s):
- * The Original Software is NetBeans. The Initial Developer of the Original
- * Software is Sun Microsystems, Inc. Portions Copyright 1997-2006 Sun
- * Microsystems, Inc. All Rights Reserved.
+ * This code is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * version 2 for more details (a copy is included in the LICENSE file that
+ * accompanied this code).
  *
- * If you wish your version of this file to be governed by only the CDDL
- * or only the GPL Version 2, indicate your decision by adding
- * "[Contributor] elects to include this software in this distribution
- * under the [CDDL or GPL Version 2] license." If you do not indicate a
- * single choice of license, a recipient has the option to distribute
- * your version of this file under either the CDDL, the GPL Version 2 or
- * to extend the choice of license to its licensees as provided above.
- * However, if you add GPL Version 2 code and therefore, elected the GPL
- * Version 2 license, then the option applies only if the new code is
- * made subject to such option by the copyright holder.
+ * You should have received a copy of the GNU General Public License version
+ * 2 along with this work; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
+ *
+ * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
+ * or visit www.oracle.com if you need additional information or have any
+ * questions.
  */
 
 package org.graalvm.visualvm.lib.common.integration;
@@ -79,6 +61,9 @@ public class IntegrationUtils {
     public static final String PLATFORM_JAVA_140 = messages.getString("IntegrationUtils_PlatformJava140"); // NOI18N
     public static final String PLATFORM_JAVA_150 = messages.getString("IntegrationUtils_PlatformJava150"); // NOI18N
     public static final String PLATFORM_JAVA_160 = messages.getString("IntegrationUtils_PlatformJava160"); // NOI18N
+    public static final String PLATFORM_JAVA_170 = messages.getString("IntegrationUtils_PlatformJava170"); // NOI18N
+    public static final String PLATFORM_JAVA_180 = messages.getString("IntegrationUtils_PlatformJava180"); // NOI18N
+    public static final String PLATFORM_JAVA_190 = messages.getString("IntegrationUtils_PlatformJava190"); // NOI18N
     public static final String PLATFORM_JAVA_CVM = messages.getString("IntegrationUtils_PlatformJavaCvm"); // NOI18N
     public static final String PLATFORM_WINDOWS_OS = messages.getString("IntegrationUtils_PlatformWindowsOs"); // NOI18N
     public static final String PLATFORM_WINDOWS_AMD64_OS = messages.getString("IntegrationUtils_PlatformWindowsAmd64Os"); // NOI18N
@@ -113,6 +98,9 @@ public class IntegrationUtils {
     private static final String JDK_140_NAME = messages.getString("IntegrationUtils_Jdk140Name"); // NOI18N
     private static final String JDK_150_NAME = messages.getString("IntegrationUtils_Jdk150Name"); // NOI18N
     private static final String JDK_160_NAME = messages.getString("IntegrationUtils_Jdk160Name"); // NOI18N
+    private static final String JDK_170_NAME = messages.getString("IntegrationUtils_Jdk170Name"); // NOI18N
+    private static final String JDK_180_NAME = messages.getString("IntegrationUtils_Jdk180Name"); // NOI18N
+    private static final String JDK_190_NAME = messages.getString("IntegrationUtils_Jdk190Name"); // NOI18N
     private static final String JDK_CVM_NAME = messages.getString("IntegrationUtils_JdkCvmName"); // NOI18N
     private static final String HTML_REMOTE_STRING = "&lt;" + messages.getString("IntegrationUtils_RemoteString") + "&gt;"; // NOI18N
     private static final String EXPORT_SETENV_MESSAGE = messages.getString("IntegrationUtils_ExportSetenvMessage"); // NOI18N
@@ -242,7 +230,7 @@ public class IntegrationUtils {
                 return false;
             }
 
-            if (line.indexOf(MODIFIED_FOR_PROFILER_STRING) != -1) {
+            if (line.contains(MODIFIED_FOR_PROFILER_STRING)) {
                 br.close();
 
                 return true;
@@ -257,7 +245,7 @@ public class IntegrationUtils {
                 return false;
             }
 
-            if (line.indexOf(MODIFIED_FOR_PROFILER_STRING) != -1) {
+            if (line.contains(MODIFIED_FOR_PROFILER_STRING)) {
                 br.close();
 
                 return true;
@@ -298,6 +286,12 @@ public class IntegrationUtils {
             return PLATFORM_JAVA_150;
         } else if (javaVersionString.equals(CommonConstants.JDK_160_STRING)) {
             return PLATFORM_JAVA_160;
+        } else if (javaVersionString.equals(CommonConstants.JDK_170_STRING)) {
+            return PLATFORM_JAVA_170;
+        } else if (javaVersionString.equals(CommonConstants.JDK_180_STRING)) {
+            return PLATFORM_JAVA_180;
+        } else if (javaVersionString.equals(CommonConstants.JDK_190_STRING)) {
+            return PLATFORM_JAVA_190;
         } else if (javaVersionString.equals(CommonConstants.JDK_CVM_STRING)) {
             return PLATFORM_JAVA_CVM;
         }
@@ -375,6 +369,12 @@ public class IntegrationUtils {
             return JDK_150_NAME;
         } else if (javaPlatform.equals(PLATFORM_JAVA_160)) {
             return JDK_160_NAME;
+        } else if (javaPlatform.equals(PLATFORM_JAVA_170)) {
+            return JDK_170_NAME;
+        } else if (javaPlatform.equals(PLATFORM_JAVA_180)) {
+            return JDK_180_NAME;
+        } else if (javaPlatform.equals(PLATFORM_JAVA_190)) {
+            return JDK_190_NAME;
         } else if (javaPlatform.equals(PLATFORM_JAVA_CVM)) {
             return JDK_CVM_NAME;
         }
@@ -397,17 +397,23 @@ public class IntegrationUtils {
         } else if (javaPlatform.equals(PLATFORM_JAVA_100)) {
             return "jdk16"; //NOI18N // for JDK 10 we use the same as for 6.0 for now
         } else if (javaPlatform.equals(PLATFORM_JAVA_110)) {
-            return "jdk16"; //NOI18N // for JDK 10 we use the same as for 6.0 for now
+            return "jdk16"; //NOI18N // for JDK 11 we use the same as for 6.0 for now
         } else if (javaPlatform.equals(PLATFORM_JAVA_120)) {
-            return "jdk16"; //NOI18N // for JDK 10 we use the same as for 6.0 for now
+            return "jdk16"; //NOI18N // for JDK 12 we use the same as for 6.0 for now
         } else if (javaPlatform.equals(PLATFORM_JAVA_130)) {
-            return "jdk16"; //NOI18N // for JDK 10 we use the same as for 6.0 for now
+            return "jdk16"; //NOI18N // for JDK 13 we use the same as for 6.0 for now
         } else if (javaPlatform.equals(PLATFORM_JAVA_140)) {
-            return "jdk16"; //NOI18N // for JDK 10 we use the same as for 6.0 for now
+            return "jdk16"; //NOI18N // for JDK 14 we use the same as for 6.0 for now
         } else if (javaPlatform.equals(PLATFORM_JAVA_150)) {
-            return "jdk16"; //NOI18N // for JDK 10 we use the same as for 6.0 for now
+            return "jdk16"; //NOI18N // for JDK 15 we use the same as for 6.0 for now
         } else if (javaPlatform.equals(PLATFORM_JAVA_160)) {
             return "jdk16"; //NOI18N // for JDK 16 we use the same as for 6.0 for now
+        } else if (javaPlatform.equals(PLATFORM_JAVA_170)) {
+            return "jdk16"; //NOI18N // for JDK 17 we use the same as for 6.0 for now
+        } else if (javaPlatform.equals(PLATFORM_JAVA_180)) {
+            return "jdk16"; //NOI18N // for JDK 18 we use the same as for 6.0 for now
+        } else if (javaPlatform.equals(PLATFORM_JAVA_190)) {
+            return "jdk16"; //NOI18N // for JDK 19 we use the same as for 6.0 for now
         } else if (javaPlatform.equals(PLATFORM_JAVA_CVM)) {
             return "cvm";  // NOI18N
         }
@@ -464,6 +470,12 @@ public class IntegrationUtils {
             return PLATFORM_JAVA_150;
         } else if (jdkVersion == Platform.JDK_160) {
             return PLATFORM_JAVA_160;
+        } else if (jdkVersion == Platform.JDK_170) {
+            return PLATFORM_JAVA_170;
+        } else if (jdkVersion == Platform.JDK_180) {
+            return PLATFORM_JAVA_180;
+        } else if (jdkVersion == Platform.JDK_190) {
+            return PLATFORM_JAVA_190;
         }
 
         return null;
