@@ -1,44 +1,26 @@
 /*
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
+ * Copyright (c) 1997, 2021, Oracle and/or its affiliates. All rights reserved.
+ * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
- * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
- *
- * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
- * Other names may be trademarks of their respective owners.
- *
- * The contents of this file are subject to the terms of either the GNU
- * General Public License Version 2 only ("GPL") or the Common
- * Development and Distribution License("CDDL") (collectively, the
- * "License"). You may not use this file except in compliance with the
- * License. You can obtain a copy of the License at
- * http://www.netbeans.org/cddl-gplv2.html
- * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
- * specific language governing permissions and limitations under the
- * License.  When distributing the software, include this License Header
- * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
+ * This code is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License version 2 only, as
+ * published by the Free Software Foundation.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Oracle in the GPL Version 2 section of the License file that
- * accompanied this code. If applicable, add the following below the
- * License Header, with the fields enclosed by brackets [] replaced by
- * your own identifying information:
- * "Portions Copyrighted [year] [name of copyright owner]"
+ * by Oracle in the LICENSE file that accompanied this code.
  *
- * Contributor(s):
- * The Original Software is NetBeans. The Initial Developer of the Original
- * Software is Sun Microsystems, Inc. Portions Copyright 1997-2006 Sun
- * Microsystems, Inc. All Rights Reserved.
+ * This code is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * version 2 for more details (a copy is included in the LICENSE file that
+ * accompanied this code).
  *
- * If you wish your version of this file to be governed by only the CDDL
- * or only the GPL Version 2, indicate your decision by adding
- * "[Contributor] elects to include this software in this distribution
- * under the [CDDL or GPL Version 2] license." If you do not indicate a
- * single choice of license, a recipient has the option to distribute
- * your version of this file under either the CDDL, the GPL Version 2 or
- * to extend the choice of license to its licensees as provided above.
- * However, if you add GPL Version 2 code and therefore, elected the GPL
- * Version 2 license, then the option applies only if the new code is
- * made subject to such option by the copyright holder.
+ * You should have received a copy of the GNU General Public License version
+ * 2 along with this work; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
+ *
+ * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
+ * or visit www.oracle.com if you need additional information or have any
+ * questions.
  */
 package org.graalvm.visualvm.lib.ui.locks;
 
@@ -54,7 +36,6 @@ import java.awt.event.ActionEvent;
 import java.awt.event.ActionListener;
 import java.awt.event.InputEvent;
 import java.awt.event.KeyEvent;
-import java.util.Collection;
 import java.util.HashSet;
 import java.util.ResourceBundle;
 import java.util.Set;
@@ -82,13 +63,12 @@ import javax.swing.border.CompoundBorder;
 import javax.swing.table.TableCellRenderer;
 import javax.swing.tree.TreeNode;
 import org.graalvm.visualvm.lib.jfluid.ProfilerClient;
-import org.graalvm.visualvm.lib.jfluid.client.ClientUtils;
-import org.graalvm.visualvm.lib.jfluid.global.ProfilingSessionStatus;
 import org.graalvm.visualvm.lib.jfluid.results.CCTNode;
-import org.graalvm.visualvm.lib.jfluid.results.RuntimeCCTNode;
 import org.graalvm.visualvm.lib.jfluid.results.locks.LockCCTNode;
-import org.graalvm.visualvm.lib.jfluid.results.locks.LockCCTProvider;
 import org.graalvm.visualvm.lib.jfluid.results.locks.LockRuntimeCCTNode;
+import org.graalvm.visualvm.lib.jfluid.utils.StringUtils;
+import org.graalvm.visualvm.lib.profiler.api.icons.Icons;
+import org.graalvm.visualvm.lib.profiler.api.icons.ProfilerIcons;
 import org.graalvm.visualvm.lib.ui.UIUtils;
 import org.graalvm.visualvm.lib.ui.components.FlatToolBar;
 import org.graalvm.visualvm.lib.ui.components.ProfilerToolbar;
@@ -105,10 +85,6 @@ import org.graalvm.visualvm.lib.ui.swing.renderer.HideableBarRenderer;
 import org.graalvm.visualvm.lib.ui.swing.renderer.McsTimeRenderer;
 import org.graalvm.visualvm.lib.ui.swing.renderer.NumberPercentRenderer;
 import org.graalvm.visualvm.lib.ui.swing.renderer.NumberRenderer;
-import org.graalvm.visualvm.lib.jfluid.utils.StringUtils;
-import org.graalvm.visualvm.lib.profiler.api.icons.Icons;
-import org.graalvm.visualvm.lib.profiler.api.icons.ProfilerIcons;
-import org.openide.util.Lookup;
 
 /**
  *
@@ -137,6 +113,7 @@ public abstract class LockContentionPanel extends DataView {
     private static final String SEARCH_MONITORS_SCOPE = messages.getString("LockContentionPanel_SearchMonitorsScope"); // NOI18N
     private static final String SEARCH_SCOPE_TOOLTIP = messages.getString("LockContentionPanel_SearchScopeTooltip"); // NOI18N
     // -----
+    private boolean refreshIsRunning;
     
     public static enum Aggregation { BY_THREADS, BY_MONITORS }
     
@@ -163,18 +140,12 @@ public abstract class LockContentionPanel extends DataView {
     private final JLabel enableLockContentionLabel2;
     
     private LockRuntimeCCTNode root;
-    private Listener cctListener;
     private long countsInMicrosec = 1;
     
     private final HideableBarRenderer hbrTime;
     private final HideableBarRenderer hbrWaits;
 
-    private static final int MIN_UPDATE_DIFF = 900;
-    private static final int MAX_UPDATE_DIFF = 1400;
-
     private long lastupdate;
-    private volatile boolean paused;
-    private volatile boolean forceRefresh;
     
     private boolean searchThreads = true;
     private boolean searchMonitors = true;
@@ -411,29 +382,23 @@ public abstract class LockContentionPanel extends DataView {
         return aggregation;
     }
     
-    public void setPaused(boolean paused) {
-        this.paused = paused;
+    public boolean isRefreshing() {
+        return refreshIsRunning;
     }
 
-    public void setForceRefresh(boolean forceRefresh) {
-        this.forceRefresh = forceRefresh;
+    public long getLastUpdate() {
+        return lastupdate;
     }
 
-    private void refreshData(final LockRuntimeCCTNode appRootNode) {
-        if ((lastupdate + MIN_UPDATE_DIFF > System.currentTimeMillis() || paused) && !forceRefresh) return;
+    public void setData(final LockRuntimeCCTNode appRootNode) {
+        refreshIsRunning = true;
         SwingUtilities.invokeLater(new Runnable() {
             public void run() {
                 root = appRootNode;
             }
         });
         prepareResults();
-        forceRefresh = false;
-    }
-
-    public void refreshData() throws ClientUtils.TargetAppOrVMTerminated {
-        if ((lastupdate + MAX_UPDATE_DIFF < System.currentTimeMillis() && !paused) || forceRefresh) {
-            getProfilerClient().forceObtainedResultsDump(true);
-        }
+//        forceRefresh = false;
     }
     
     public void resetData() {
@@ -445,22 +410,6 @@ public abstract class LockContentionPanel extends DataView {
         });
     }
     
-    private class Listener implements LockCCTProvider.Listener {
-
-        @Override
-        public void cctEstablished(final RuntimeCCTNode appRootNode, boolean empty) {
-            if (!empty && appRootNode instanceof LockRuntimeCCTNode) {
-                refreshData((LockRuntimeCCTNode)appRootNode);
-            }
-        }
-
-        @Override
-        public void cctReset() {
-            resetData();
-        }  
-    }
-    
-    
     public void addSaveViewAction(AbstractAction saveViewAction) {
         Component actionButton = toolbar.add(saveViewAction);
         toolbar.remove(actionButton);
@@ -478,7 +427,7 @@ public abstract class LockContentionPanel extends DataView {
     public void prepareResults() {
         SwingUtilities.invokeLater(new Runnable() {
             public void run() {
-                if (root == null) return;
+                if (root == null) {refreshIsRunning = false; return; }
                 
                 LockCCTNode newRoot = null;
                 switch (aggregation) {
@@ -495,51 +444,11 @@ public abstract class LockContentionPanel extends DataView {
                 hbrWaits.setMaxValue(newRoot.getWaits());
                 treeTableModel.setRoot(newRoot);
                 lastupdate = System.currentTimeMillis();
+                refreshIsRunning = false;
             }
         });
     }
     
-    
-    public void profilingSessionFinished() {
-        enableLockContentionButton.setEnabled(false);
-        enableLockContentionButton.setVisible(false);
-        enableLockContentionLabel1.setVisible(false);
-        enableLockContentionLabel2.setVisible(true);
-        if (cctListener != null) {
-            Collection<? extends LockCCTProvider> locksCCTProviders = Lookup.getDefault().lookupAll(LockCCTProvider.class);
-            assert !locksCCTProviders.isEmpty();
-            for (LockCCTProvider provider : locksCCTProviders) {
-                provider.removeListener(cctListener);
-            }
-            cctListener = null;
-        }
-    }
-
-    public void profilingSessionStarted() {
-        ProfilingSessionStatus session = getProfilerClient().getStatus();
-        countsInMicrosec = session.timerCountsInSecond[0] / 1000000L;
-//        countsInMicrosec = 1;
-
-        if (cctListener == null) {
-            cctListener = new Listener();
-            Collection<? extends LockCCTProvider> locksCCTProviders = Lookup.getDefault().lookupAll(LockCCTProvider.class);
-            assert !locksCCTProviders.isEmpty();
-            for (LockCCTProvider provider : locksCCTProviders) {
-                provider.addListener(cctListener);
-            }
-        } else {
-            treeTable.clearSelection();
-            treeTableModel.setRoot(LockCCTNode.EMPTY);
-//            treeTable.clearSelection();
-//            treeTable.updateTreeTable();
-        }
-        
-        enableLockContentionButton.setEnabled(true);
-        enableLockContentionButton.setVisible(true);
-        enableLockContentionLabel1.setVisible(true);
-        enableLockContentionLabel2.setVisible(false);
-    }
-    
     public void lockContentionDisabled() {
         ((CardLayout)(contentPanel.getLayout())).show(contentPanel, "DISABLED"); // NOI18N
 //        updateZoomButtonsEnabledState();
