@@ -1,44 +1,26 @@
 /*
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
+ * Copyright (c) 1997, 2021, Oracle and/or its affiliates. All rights reserved.
+ * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
- * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
- *
- * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
- * Other names may be trademarks of their respective owners.
- *
- * The contents of this file are subject to the terms of either the GNU
- * General Public License Version 2 only ("GPL") or the Common
- * Development and Distribution License("CDDL") (collectively, the
- * "License"). You may not use this file except in compliance with the
- * License. You can obtain a copy of the License at
- * http://www.netbeans.org/cddl-gplv2.html
- * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
- * specific language governing permissions and limitations under the
- * License.  When distributing the software, include this License Header
- * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
+ * This code is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License version 2 only, as
+ * published by the Free Software Foundation.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Oracle in the GPL Version 2 section of the License file that
- * accompanied this code. If applicable, add the following below the
- * License Header, with the fields enclosed by brackets [] replaced by
- * your own identifying information:
- * "Portions Copyrighted [year] [name of copyright owner]"
+ * by Oracle in the LICENSE file that accompanied this code.
  *
- * Contributor(s):
- * The Original Software is NetBeans. The Initial Developer of the Original
- * Software is Sun Microsystems, Inc. Portions Copyright 1997-2006 Sun
- * Microsystems, Inc. All Rights Reserved.
+ * This code is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * version 2 for more details (a copy is included in the LICENSE file that
+ * accompanied this code).
  *
- * If you wish your version of this file to be governed by only the CDDL
- * or only the GPL Version 2, indicate your decision by adding
- * "[Contributor] elects to include this software in this distribution
- * under the [CDDL or GPL Version 2] license." If you do not indicate a
- * single choice of license, a recipient has the option to distribute
- * your version of this file under either the CDDL, the GPL Version 2 or
- * to extend the choice of license to its licensees as provided above.
- * However, if you add GPL Version 2 code and therefore, elected the GPL
- * Version 2 license, then the option applies only if the new code is
- * made subject to such option by the copyright holder.
+ * You should have received a copy of the GNU General Public License version
+ * 2 along with this work; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
+ *
+ * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
+ * or visit www.oracle.com if you need additional information or have any
+ * questions.
  */
 
 package org.graalvm.visualvm.lib.jfluid;
@@ -157,7 +139,7 @@ public class TargetAppRunner implements CommonConstants {
     private ProfilerClient profilerClient;
     private ProfilerEngineSettings settings;
     private ProfilingSessionStatus status;
-    private Collection<ProfilingEventListener> listeners = new CopyOnWriteArraySet<ProfilingEventListener>();
+    private Collection<ProfilingEventListener> listeners = new CopyOnWriteArraySet<>();
     private boolean targetAppIsSuspended;
 
     //~ Constructors -------------------------------------------------------------------------------------------------------------    
@@ -234,7 +216,6 @@ public class TargetAppRunner implements CommonConstants {
      * Attaches to a running application. It is expected that prepareForAttach method is called before this one
      * to prepare the target app environment for attaching.
      *
-     * @throws IOException in case sending signal to target app failed
      */
     public boolean attachToTargetVM() {
         if (connectToStartedVMAndStartTA(1, false)) {
@@ -692,17 +673,7 @@ public class TargetAppRunner implements CommonConstants {
         String libPath = settings.getJFluidRootDirName();
         String jdkVer = settings.getTargetJDKVersionString();
 
-        if (jdkVer.equals(JDK_16_STRING)
-            || jdkVer.equals(JDK_17_STRING)
-            || jdkVer.equals(JDK_18_STRING)
-            || jdkVer.equals(JDK_19_STRING)
-            || jdkVer.equals(JDK_100_STRING)
-            || jdkVer.equals(JDK_110_STRING)
-            || jdkVer.equals(JDK_120_STRING)
-            || jdkVer.equals(JDK_130_STRING)
-            || jdkVer.equals(JDK_140_STRING)
-            || jdkVer.equals(JDK_150_STRING)
-            || jdkVer.equals(JDK_160_STRING)) {
+        if (!jdkVer.equals(JDK_CVM_STRING) && !jdkVer.equals(JDK_UNSUPPORTED_STRING)) {
             // for now the 1.6 and 1.7 and 1.8 and 9 and 10+ profiling uses the same jfluid-server as 1.5
             jdkVer = JDK_15_STRING;
         }
@@ -755,7 +726,7 @@ public class TargetAppRunner implements CommonConstants {
 
         String jdk = settings.getTargetJDKVersionString();
         if (!jdk.equals(Platform.JDK_CVM_STRING) &&
-            !jdk.equals(Platform.JDK_UNSUPPORTED)
+            !jdk.equals(Platform.JDK_UNSUPPORTED_STRING)
         ) {
             int architecture = settings.getSystemArchitecture();
             String jfNativeLibFullName = Platform.getAgentNativeLibFullName(settings.getJFluidRootDirName(), false,
@@ -763,7 +734,14 @@ public class TargetAppRunner implements CommonConstants {
                                                                             architecture);
             commands.add("-agentpath:" + jfNativeLibFullName); // NOI18N
             if (Platform.isSolaris() && architecture == ARCH_64) {
-                commands.add("-d64");
+                if (jdkVer.equals(JDK_15_STRING)
+                    || jdkVer.equals(JDK_16_STRING)
+                    || jdkVer.equals(JDK_17_STRING)
+                    || jdkVer.equals(JDK_18_STRING)
+                    || jdkVer.equals(JDK_19_STRING)) {
+                    // -d64 is supported from JDK 1.5 to JDK 9
+                    commands.add("-d64");
+                }
             }
         }
 
@@ -781,8 +759,8 @@ public class TargetAppRunner implements CommonConstants {
         if (Platform.isLinux() && settings.getTargetJDKVersionString().equals(Platform.JDK_16_STRING)) {
             commands.add("-XX:+UseLinuxPosixThreadCPUClocks"); // NOI18N
         }
-        for (int i = 0; i < newJVMArgs.length; i++) {
-            commands.add(newJVMArgs[i]);
+        for (String newJVMArg : newJVMArgs) {
+            commands.add(newJVMArg);
         }
 
         // debugging property for agent side - wire I/O
@@ -810,8 +788,8 @@ public class TargetAppRunner implements CommonConstants {
             commands.add(mainClassName);
         }
 
-        for (int i = 0; i < mainArgs.length; i++) {
-            commands.add(mainArgs[i]);
+        for (String mainArg : mainArgs) {
+            commands.add(mainArg);
         }
 
         String[] cmdArray = (String[])commands.toArray(new String[0]);
@@ -835,8 +813,8 @@ public class TargetAppRunner implements CommonConstants {
         } catch (IOException ex) {
             StringBuilder sb = new StringBuilder();
 
-            for (int i = 0; i < cmdArray.length; i++) {
-                sb.append(cmdArray[i]).append('\n'); // NOI18N
+            for (String cmdArray1 : cmdArray) {
+                sb.append(cmdArray1).append('\n'); // NOI18N
             }
 
             appStatusHandler.displayError(MessageFormat.format(ERROR_STARTING_JVM_MSG, new Object[] { sb, ex }));
