@@ -1,44 +1,26 @@
 /*
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
+ * Copyright (c) 1997, 2021, Oracle and/or its affiliates. All rights reserved.
+ * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
- * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
- *
- * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
- * Other names may be trademarks of their respective owners.
- *
- * The contents of this file are subject to the terms of either the GNU
- * General Public License Version 2 only ("GPL") or the Common
- * Development and Distribution License("CDDL") (collectively, the
- * "License"). You may not use this file except in compliance with the
- * License. You can obtain a copy of the License at
- * http://www.netbeans.org/cddl-gplv2.html
- * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
- * specific language governing permissions and limitations under the
- * License.  When distributing the software, include this License Header
- * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
+ * This code is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License version 2 only, as
+ * published by the Free Software Foundation.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Oracle in the GPL Version 2 section of the License file that
- * accompanied this code. If applicable, add the following below the
- * License Header, with the fields enclosed by brackets [] replaced by
- * your own identifying information:
- * "Portions Copyrighted [year] [name of copyright owner]"
+ * by Oracle in the LICENSE file that accompanied this code.
  *
- * Contributor(s):
- * The Original Software is NetBeans. The Initial Developer of the Original
- * Software is Sun Microsystems, Inc. Portions Copyright 1997-2006 Sun
- * Microsystems, Inc. All Rights Reserved.
+ * This code is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * version 2 for more details (a copy is included in the LICENSE file that
+ * accompanied this code).
  *
- * If you wish your version of this file to be governed by only the CDDL
- * or only the GPL Version 2, indicate your decision by adding
- * "[Contributor] elects to include this software in this distribution
- * under the [CDDL or GPL Version 2] license." If you do not indicate a
- * single choice of license, a recipient has the option to distribute
- * your version of this file under either the CDDL, the GPL Version 2 or
- * to extend the choice of license to its licensees as provided above.
- * However, if you add GPL Version 2 code and therefore, elected the GPL
- * Version 2 license, then the option applies only if the new code is
- * made subject to such option by the copyright holder.
+ * You should have received a copy of the GNU General Public License version
+ * 2 along with this work; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
+ *
+ * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
+ * or visit www.oracle.com if you need additional information or have any
+ * questions.
  */
 
 package org.graalvm.visualvm.lib.jfluid.global;
@@ -82,11 +64,6 @@ public class Platform implements CommonConstants {
      */
     public static final int OS_LINUX = 16;
 
-    /**
-     * Operating system is HP-UX.
-     */
-    public static final int OS_HP = 32;
-
     /**
      * Operating system is IBM AIX.
      */
@@ -145,7 +122,7 @@ public class Platform implements CommonConstants {
     /**
      * A mask for Unix platforms.
      */
-    public static final int OS_UNIX_MASK = OS_SOLARIS | OS_LINUX | OS_HP | OS_AIX | OS_IRIX | OS_SUNOS | OS_TRU64 | OS_MAC;
+    public static final int OS_UNIX_MASK = OS_SOLARIS | OS_LINUX | OS_AIX | OS_IRIX | OS_SUNOS | OS_TRU64 | OS_MAC;
 
     /**
      * The operating system on which the tool runs
@@ -158,7 +135,7 @@ public class Platform implements CommonConstants {
     //~ Methods ------------------------------------------------------------------------------------------------------------------
 
     /**
-     * Given the name of the directory containing the JFluid native libaries (either just the root JFluid libs dir,
+     * Given the name of the directory containing the JFluid native libraries (either just the root JFluid libs dir,
      * or really the full path, depending on fullPathToLibSpecified parameter), return the full platform-dependent
      * name for the "profilerinterface" library contained in that directory. If non-null jdkString is specified, it
      * is used in the resulting path; otherwise the VM is queried for its version and the resulting string is used.
@@ -182,11 +159,8 @@ public class Platform implements CommonConstants {
 
         is64bitArch = architecture == ARCH_64;
 
-        if (jdkString.equals(JDK_17_STRING) || jdkString.equals(JDK_18_STRING)
-            || jdkString.equals(JDK_19_STRING) || jdkString.equals(JDK_100_STRING)
-            || jdkString.equals(JDK_110_STRING) || jdkString.equals(JDK_120_STRING)
-            || jdkString.equals(JDK_130_STRING) || jdkString.equals(JDK_140_STRING)
-            || jdkString.equals(JDK_150_STRING) || jdkString.equals(JDK_160_STRING)) {
+        if (!jdkString.equals(JDK_15_STRING) && !jdkString.equals(JDK_CVM_STRING)
+            && !jdkString.equals(JDK_UNSUPPORTED_STRING)) {
             // for now, we use the same libs for 1.6 and 1.7 and 1.8 and 1.9 and 10+
             jdkString = JDK_16_STRING;
         }
@@ -203,8 +177,6 @@ public class Platform implements CommonConstants {
             libSuffix = ".dll"; // Windows // NOI18N
         } else if (isMac()) {
             libSuffix = ".jnilib"; // Mac // NOI18N
-        } else if (isHpux()) {
-            libSuffix = ".sl"; // HP-UX // NOI18N
         } else {
             libSuffix = ".so"; // UNIXes // NOI18N
         }
@@ -219,8 +191,6 @@ public class Platform implements CommonConstants {
                libSubDir = "mac";
             } else if (isLinux()) {
                libSubDir = "linux"; // NOI18N
-            } else if (isHpux()) {
-               libSubDir = "hpux"; // NOI18N
             } else {
                libSubDir = "solaris"; // NOI18N
             }
@@ -231,8 +201,6 @@ public class Platform implements CommonConstants {
                     procArch = "amd64"; // NOI18N
                 } else if (isSolarisSparc()) {
                     procArch = "sparcv9"; // NOI18N
-                } else if (isHpux()) {
-                    procArch = "pa_risc2.0w"; // NOI18N
                 } else if (isLinuxAarch64()) {
                     procArch = "aarch64"; // NOI18N
                 }
@@ -242,8 +210,6 @@ public class Platform implements CommonConstants {
                     procArch = "i386"; // NOI18N
                 } else if (isSolarisSparc()) {
                     procArch = "sparc"; // NOI18N
-                } else if (isHpux()) {
-                    procArch = "pa_risc2.0"; // NOI18N
                 } else if (isLinuxArm()) {
                     if (isLinuxArmVfpHflt()) {
                         procArch = "arm-vfp-hflt"; // NOI18N
@@ -327,6 +293,12 @@ public class Platform implements CommonConstants {
             jdkVersion = JDK_150;
         } else if (isJavaVersion(javaVersion,"16")) { // NOI18N
             jdkVersion = JDK_160;
+        } else if (isJavaVersion(javaVersion,"17")) { // NOI18N
+            jdkVersion = JDK_170;
+        } else if (isJavaVersion(javaVersion,"18")) { // NOI18N
+            jdkVersion = JDK_180;
+        } else if (isJavaVersion(javaVersion,"19")) { // NOI18N
+            jdkVersion = JDK_190;
         } else if (javaVersion.equals("CVM")) { // NOI18N
             jdkVersion = JDK_CVM;
         } else {
@@ -374,6 +346,9 @@ public class Platform implements CommonConstants {
             case JDK_140: return JDK_140_STRING;
             case JDK_150: return JDK_150_STRING;
             case JDK_160: return JDK_160_STRING;
+            case JDK_170: return JDK_170_STRING;
+            case JDK_180: return JDK_180_STRING;
+            case JDK_190: return JDK_190_STRING;
             case JDK_CVM: return JDK_CVM_STRING;
             case JDK_UNSUPPORTED: return JDK_UNSUPPORTED_STRING;
         }
@@ -428,10 +403,6 @@ public class Platform implements CommonConstants {
         return (getOperatingSystem() == OS_MAC);
     }
     
-    public static boolean isHpux() {
-        return (getOperatingSystem() == OS_HP);
-    }
-    
     /**
      * Get the operating system on which we are is running.
      * Returns one of the <code>OS_*</code> constants (such as {@link #OS_WINNT})
@@ -470,9 +441,6 @@ public class Platform implements CommonConstants {
         } else if (osName.endsWith("Linux")) { // NOI18N
 
             return OS_LINUX;
-        } else if ("HP-UX".equals(osName)) { // NOI18N
-
-            return OS_HP;
         } else if ("AIX".equals(osName)) { // NOI18N
 
             return OS_AIX;
