@@ -1,43 +1,26 @@
 /*
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
+ * Copyright (c) 2010, 2021, Oracle and/or its affiliates. All rights reserved.
+ * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
- * Copyright 2010 Oracle and/or its affiliates. All rights reserved.
- *
- * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
- * Other names may be trademarks of their respective owners.
- *
- * The contents of this file are subject to the terms of either the GNU
- * General Public License Version 2 only ("GPL") or the Common
- * Development and Distribution License("CDDL") (collectively, the
- * "License"). You may not use this file except in compliance with the
- * License. You can obtain a copy of the License at
- * http://www.netbeans.org/cddl-gplv2.html
- * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
- * specific language governing permissions and limitations under the
- * License.  When distributing the software, include this License Header
- * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
+ * This code is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License version 2 only, as
+ * published by the Free Software Foundation.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Oracle in the GPL Version 2 section of the License file that
- * accompanied this code. If applicable, add the following below the
- * License Header, with the fields enclosed by brackets [] replaced by
- * your own identifying information:
- * "Portions Copyrighted [year] [name of copyright owner]"
+ * by Oracle in the LICENSE file that accompanied this code.
  *
- * If you wish your version of this file to be governed by only the CDDL
- * or only the GPL Version 2, indicate your decision by adding
- * "[Contributor] elects to include this software in this distribution
- * under the [CDDL or GPL Version 2] license." If you do not indicate a
- * single choice of license, a recipient has the option to distribute
- * your version of this file under either the CDDL, the GPL Version 2 or
- * to extend the choice of license to its licensees as provided above.
- * However, if you add GPL Version 2 code and therefore, elected the GPL
- * Version 2 license, then the option applies only if the new code is
- * made subject to such option by the copyright holder.
+ * This code is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * version 2 for more details (a copy is included in the LICENSE file that
+ * accompanied this code).
  *
- * Contributor(s):
+ * You should have received a copy of the GNU General Public License version
+ * 2 along with this work; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
  *
- * Portions Copyrighted 2008 Sun Microsystems, Inc.
+ * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
+ * or visit www.oracle.com if you need additional information or have any
+ * questions.
  */
 package org.graalvm.visualvm.lib.jfluid.results.cpu;
 
@@ -51,6 +34,7 @@ import java.util.Iterator;
 import java.util.List;
 import java.util.ListIterator;
 import java.util.Map;
+import java.util.Objects;
 import java.util.Set;
 import java.util.concurrent.atomic.AtomicReference;
 import org.graalvm.visualvm.lib.jfluid.filters.InstrumentationFilter;
@@ -65,7 +49,7 @@ import org.graalvm.visualvm.lib.jfluid.results.cpu.cct.nodes.TimedCPUCCTNode;
  * @author Jaroslav Bachorik, Tomas Hurka
  */
 public class StackTraceSnapshotBuilder {
-    
+
     static final char NAME_SIG_SPLITTER = '|';
     private static final StackTraceElement[] NO_STACK_TRACE = new StackTraceElement[0];
     private static final boolean COLLECT_TWO_TIMESTAMPS = true;
@@ -118,6 +102,12 @@ public class StackTraceSnapshotBuilder {
         new MethodInfo("sun.nio.ch.Net", "connect0[native](boolean, java.io.FileDescriptor, java.net.InetAddress, int) : int"), // NOI18N
         new MethodInfo("java.lang.ProcessHandleImpl", "waitForProcessExit0[native]"), // NOI18N
         new MethodInfo("java.lang.ProcessHandleImpl", "waitForProcessExit0[native](long, boolean) : int"), // NOI18N
+        new MethodInfo("java.net.PlainSocketImpl", "accept0[native]"), // NOI18N
+        new MethodInfo("java.net.PlainSocketImpl", "accept0[native](int, java.net.InetSocketAddress[]) : int"), // NOI18N
+        new MethodInfo("sun.nio.ch.KQueue", "keventPoll[native]"), // NOI18N
+        new MethodInfo("sun.nio.ch.KQueue", "keventPoll[native](int, long, int) : int"), // NOI18N
+        new MethodInfo("sun.nio.ch.KQueue", "poll[native]"), // NOI18N
+        new MethodInfo("sun.nio.ch.KQueue", "poll[native](int, long, int, long) : int"), // NOI18N
     }));
 
     private InstrumentationFilter filter;
@@ -174,10 +164,13 @@ public class StackTraceSnapshotBuilder {
                 return false;
             }
             final MethodInfo other = (MethodInfo) obj;
-            if ((className == null) ? (other.className != null) : !className.equals(other.className)) {
+            if (!Objects.equals(className, other.className)) {
                 return false;
             }
-            if ((methodName == null) ? (other.methodName != null) : !methodName.equals(other.methodName)) {
+            if (!Objects.equals(methodName, other.methodName)) {
+                return false;
+            }
+            if (!Objects.equals(signature, other.signature)) {
                 return false;
             }
             return true;
@@ -188,6 +181,7 @@ public class StackTraceSnapshotBuilder {
             int hash = 5;
             hash = 29 * hash + (this.className != null ? this.className.hashCode() : 0);
             hash = 29 * hash + (this.methodName != null ? this.methodName.hashCode() : 0);
+            hash = 29 * hash + (this.signature != null ? this.signature.hashCode() : 0);
             return hash;
         }
         
@@ -266,11 +260,11 @@ public class StackTraceSnapshotBuilder {
         
     }
     
-    final List<Long> threadIds = new ArrayList<Long>();
-    final List<String> threadNames = new ArrayList<String>();
-    final List<byte[]> threadCompactData = new ArrayList<byte[]>();
-    final List<MethodInfo> methodInfos = new ArrayList<MethodInfo>();
-    final Map<MethodInfo,Integer> methodInfoMap = new HashMap<MethodInfo,Integer>();
+    final List<Long> threadIds = new ArrayList<>();
+    final List<String> threadNames = new ArrayList<>();
+    final List<byte[]> threadCompactData = new ArrayList<>();
+    final List<MethodInfo> methodInfos = new ArrayList<>();
+    final Map<MethodInfo,Integer> methodInfoMap = new HashMap<>();
     final MethodInfoMapper mapper = new MethodInfoMapper() {
         
         @Override
@@ -304,10 +298,10 @@ public class StackTraceSnapshotBuilder {
     final Object stampLock = new Object();
     // @GuardedBy stampLock
     long currentDumpTimeStamp = -1L;
-    final AtomicReference<Map<Long, SampledThreadInfo>> lastStackTrace = new AtomicReference<Map<Long, SampledThreadInfo>>(Collections.EMPTY_MAP);
+    final AtomicReference<Map<Long, SampledThreadInfo>> lastStackTrace = new AtomicReference<>(Collections.EMPTY_MAP);
     int stackTraceCount = 0;
     //    int builderBatchSize;
-    final Set<String> ignoredThreadNames = new HashSet<String>();
+    final Set<String> ignoredThreadNames = new HashSet<>();
     final Map<Long,Long> threadtimes = new HashMap();
     
     {
