@@ -1,44 +1,26 @@
 /*
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
+ * Copyright (c) 1997, 2021, Oracle and/or its affiliates. All rights reserved.
+ * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
- * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
- *
- * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
- * Other names may be trademarks of their respective owners.
- *
- * The contents of this file are subject to the terms of either the GNU
- * General Public License Version 2 only ("GPL") or the Common
- * Development and Distribution License("CDDL") (collectively, the
- * "License"). You may not use this file except in compliance with the
- * License. You can obtain a copy of the License at
- * http://www.netbeans.org/cddl-gplv2.html
- * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
- * specific language governing permissions and limitations under the
- * License.  When distributing the software, include this License Header
- * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
+ * This code is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License version 2 only, as
+ * published by the Free Software Foundation.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Oracle in the GPL Version 2 section of the License file that
- * accompanied this code. If applicable, add the following below the
- * License Header, with the fields enclosed by brackets [] replaced by
- * your own identifying information:
- * "Portions Copyrighted [year] [name of copyright owner]"
+ * by Oracle in the LICENSE file that accompanied this code.
  *
- * Contributor(s):
- * The Original Software is NetBeans. The Initial Developer of the Original
- * Software is Sun Microsystems, Inc. Portions Copyright 1997-2006 Sun
- * Microsystems, Inc. All Rights Reserved.
+ * This code is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * version 2 for more details (a copy is included in the LICENSE file that
+ * accompanied this code).
  *
- * If you wish your version of this file to be governed by only the CDDL
- * or only the GPL Version 2, indicate your decision by adding
- * "[Contributor] elects to include this software in this distribution
- * under the [CDDL or GPL Version 2] license." If you do not indicate a
- * single choice of license, a recipient has the option to distribute
- * your version of this file under either the CDDL, the GPL Version 2 or
- * to extend the choice of license to its licensees as provided above.
- * However, if you add GPL Version 2 code and therefore, elected the GPL
- * Version 2 license, then the option applies only if the new code is
- * made subject to such option by the copyright holder.
+ * You should have received a copy of the GNU General Public License version
+ * 2 along with this work; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
+ *
+ * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
+ * or visit www.oracle.com if you need additional information or have any
+ * questions.
  */
 
 package org.graalvm.visualvm.lib.jfluid.utils;
@@ -80,7 +62,7 @@ public class MiscUtils {
     private static final String VM_VERSION_MSG;
     private static final String VM_UNKNOWN_MSG;
     private static final String VM_INCOMPATIBLE_MSG;
-    
+
     static {
         ResourceBundle messages = ResourceBundle.getBundle("org.graalvm.visualvm.lib.jfluid.utils.Bundle"); // NOI18N
         NOT_DIRECTORY_MSG = messages.getString("MiscUtils_NotDirectoryMsg"); // NOI18N
@@ -134,18 +116,18 @@ public class MiscUtils {
             return;
         }
 
-        for (int i = 0; i < fileNames.length; i++) {
-            if (fileNames[i].endsWith(".class")) { // NOI18N
+        for (String fileName : fileNames) {
+            if (fileName.endsWith(".class")) { // NOI18N
 
                 String className = packageName
-                                   + (removeClassExt ? fileNames[i].substring(0, fileNames[i].length() - 6) : fileNames[i]);
+                                   + (removeClassExt ? fileName.substring(0, fileName.length() - 6) : fileName);
                 res.add(className.intern());
             } else {
-                String subDirName = dirName + File.separator + fileNames[i];
+                String subDirName = dirName + File.separator + fileName;
                 File subDir = new File(subDirName);
 
                 if (subDir.exists() && subDir.isDirectory()) {
-                    String subPackage = packageName + fileNames[i] + "/"; // NOI18N
+                    String subPackage = packageName + fileName + "/"; // NOI18N
                     getAllClassesInDir(subDirName, subPackage, removeClassExt, res);
                 }
             }
@@ -308,7 +290,7 @@ public class MiscUtils {
         List liveComponents = getPathComponents(path, true, workingDir);
         StringBuilder buf = new StringBuilder(liveComponents.size() * 10);
 
-        if (liveComponents.size() > 0) {
+        if (!liveComponents.isEmpty()) {
             buf.append((String) liveComponents.get(0));
 
             for (int i = 1; i < liveComponents.size(); i++) {
@@ -370,39 +352,39 @@ public class MiscUtils {
     private static void getClassPathFromManifest(String jarPath,List pathList) throws IOException, URISyntaxException {
         if (jarPath.toLowerCase(Locale.ENGLISH).endsWith(".jar")) {   // NOI18N
             File pathFile = new File(jarPath);
-            JarFile jarFile = new JarFile(pathFile);
-            Manifest manifest = jarFile.getManifest();
-            
-            if (manifest != null) {
-                Attributes attrs = manifest.getMainAttributes();
+            try (JarFile jarFile = new JarFile(pathFile)) {
+                Manifest manifest = jarFile.getManifest();
 
-                if (attrs != null) {
-                    String jarCp = attrs.getValue(Attributes.Name.CLASS_PATH);
+                if (manifest != null) {
+                    Attributes attrs = manifest.getMainAttributes();
 
-                    if (jarCp != null) {
-                        File parent = pathFile.getParentFile();
-                        StringTokenizer tokens = new StringTokenizer(jarCp);
-                        
-                        while(tokens.hasMoreTokens()) {
-                            URI fileUri = new URI(tokens.nextToken());
-                            File cpFile;
-                            String cpName;
-                            
-                            if (!fileUri.isAbsolute()) {
-                                cpFile = new File(parent,fileUri.getPath());
-                            } else {
-                                cpFile = new File(fileUri);
-                            }
-                            cpName = getCanonicalPath(cpFile);
-                            if (cpName != null && !pathList.contains(cpName)) {
-                                pathList.add(cpName);
-                                getClassPathFromManifest(cpName,pathList);
+                    if (attrs != null) {
+                        String jarCp = attrs.getValue(Attributes.Name.CLASS_PATH);
+
+                        if (jarCp != null) {
+                            File parent = pathFile.getParentFile();
+                            StringTokenizer tokens = new StringTokenizer(jarCp);
+
+                            while(tokens.hasMoreTokens()) {
+                                URI fileUri = new URI(tokens.nextToken());
+                                File cpFile;
+                                String cpName;
+
+                                if (!fileUri.isAbsolute()) {
+                                    cpFile = new File(parent,fileUri.getPath());
+                                } else {
+                                    cpFile = new File(fileUri);
+                                }
+                                cpName = getCanonicalPath(cpFile);
+                                if (cpName != null && !pathList.contains(cpName)) {
+                                    pathList.add(cpName);
+                                    getClassPathFromManifest(cpName,pathList);
+                                }
                             }
                         }
                     }
                 }
             }
-            jarFile.close();
         }
     }
     
@@ -503,20 +485,14 @@ public class MiscUtils {
     public static void deleteHeapTempFiles() {
         if (Platform.isWindows()) { // this is workaroud for JDK bug #6359560
 
-            try {
-                File tempDir = new File(System.getProperty("java.io.tmpdir")); // NOI18N
-                DirectoryStream<Path> files = Files.newDirectoryStream(tempDir.toPath());
+            File tempDir = new File(System.getProperty("java.io.tmpdir")); // NOI18N
+            try (DirectoryStream<Path> files = Files.newDirectoryStream(tempDir.toPath())) {
+                for (Path p : files) {
+                    String fname = p.toFile().getName();
 
-                try {
-                    for (Path p : files) {
-                        String fname = p.toFile().getName();
-
-                        if (fname.startsWith("NBProfiler") && (fname.endsWith(".map") || fname.endsWith(".ref") || fname.endsWith(".gc"))) { // NOI18N
-                            Files.delete(p);
-                        }
+                    if (fname.startsWith("NBProfiler") && (fname.endsWith(".map") || fname.endsWith(".ref") || fname.endsWith(".gc"))) { // NOI18N
+                        Files.delete(p);
                     }
-                } finally {
-                    files.close();
                 }
             } catch (IOException ex) {
                 System.err.println("deleteHeapTempFiles failed");   // NOI18N
@@ -600,22 +576,19 @@ public class MiscUtils {
             checkFile(fileOrZip.getFile(), false);
         }
 
-        InputStream in = fileOrZip.getInputStream();
-        int len = (int) fileOrZip.getLength();
-        byte[] buf = new byte[len];
-        int readBytes;
-        int ofs = 0;
-        int remBytes = len;
-
-        do {
-            readBytes = in.read(buf, ofs, remBytes);
-            ofs += readBytes;
-            remBytes -= readBytes;
-        } while (ofs < len);
-
-        in.close();
-
-        return buf;
+        try (InputStream in = fileOrZip.getInputStream()) {
+            int len = (int) fileOrZip.getLength();
+            byte[] buf = new byte[len];
+            int readBytes;
+            int ofs = 0;
+            int remBytes = len;
+            do {
+                readBytes = in.read(buf, ofs, remBytes);
+                ofs += readBytes;
+                remBytes -= readBytes;
+            } while (ofs < len);
+            return buf;
+        }
     }
 
     private static String getDate() {
