@@ -1,43 +1,26 @@
 /*
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
+ * Copyright (c) 2013, 2021, Oracle and/or its affiliates. All rights reserved.
+ * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
- * Copyright 2013 Oracle and/or its affiliates. All rights reserved.
- *
- * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
- * Other names may be trademarks of their respective owners.
- *
- * The contents of this file are subject to the terms of either the GNU
- * General Public License Version 2 only ("GPL") or the Common
- * Development and Distribution License("CDDL") (collectively, the
- * "License"). You may not use this file except in compliance with the
- * License. You can obtain a copy of the License at
- * http://www.netbeans.org/cddl-gplv2.html
- * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
- * specific language governing permissions and limitations under the
- * License.  When distributing the software, include this License Header
- * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
+ * This code is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License version 2 only, as
+ * published by the Free Software Foundation.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Oracle in the GPL Version 2 section of the License file that
- * accompanied this code. If applicable, add the following below the
- * License Header, with the fields enclosed by brackets [] replaced by
- * your own identifying information:
- * "Portions Copyrighted [year] [name of copyright owner]"
+ * by Oracle in the LICENSE file that accompanied this code.
  *
- * If you wish your version of this file to be governed by only the CDDL
- * or only the GPL Version 2, indicate your decision by adding
- * "[Contributor] elects to include this software in this distribution
- * under the [CDDL or GPL Version 2] license." If you do not indicate a
- * single choice of license, a recipient has the option to distribute
- * your version of this file under either the CDDL, the GPL Version 2 or
- * to extend the choice of license to its licensees as provided above.
- * However, if you add GPL Version 2 code and therefore, elected the GPL
- * Version 2 license, then the option applies only if the new code is
- * made subject to such option by the copyright holder.
+ * This code is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * version 2 for more details (a copy is included in the LICENSE file that
+ * accompanied this code).
  *
- * Contributor(s):
+ * You should have received a copy of the GNU General Public License version
+ * 2 along with this work; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
  *
- * Portions Copyrighted 2013 Sun Microsystems, Inc.
+ * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
+ * or visit www.oracle.com if you need additional information or have any
+ * questions.
  */
 package org.graalvm.visualvm.lib.profiler.heapwalk.details.netbeans;
 
@@ -115,133 +98,159 @@ public class PlatformDetailsProvider extends DetailsProvider.Basic {
     }
 
     private String getDetailsStringImpl(String className, Instance instance) {
-        if (STANDARD_MODULE.equals(className))  {
-            String codeName = DetailsUtils.getInstanceFieldString(instance, "codeName");     // NOI18N
-            if (codeName != null) {
-                return codeName;
-            }
-            return DetailsUtils.getInstanceFieldString(instance, "data");     // NOI18N
-        } else if (DEPENDENCY.equals(className)) {
-            String name = DetailsUtils.getInstanceFieldString(instance, "name");     // NOI18N
-            String version = DetailsUtils.getInstanceFieldString(instance, "version");     // NOI18N
-            int type = DetailsUtils.getIntFieldValue(instance, "type", -1); // NOI18N
-            int comparison = DetailsUtils.getIntFieldValue(instance, "comparison", -1); // NOI18N
-            return DependencyResolver.toString(name, version, type, comparison);
-        } else if (SPECIFICATION_VERSION.equals(className)) {
-            PrimitiveArrayInstance digits = (PrimitiveArrayInstance) instance.getValueOfField("digits"); // NOI18N
-            if (digits != null) {
-                StringBuilder specVersion = new StringBuilder();
-
-                for (Object d : digits.getValues()) {
-                   specVersion.append(d);
-                   specVersion.append('.');
+        switch (className) {
+            case STANDARD_MODULE: {
+                String codeName = DetailsUtils.getInstanceFieldString(instance, "codeName");     // NOI18N
+                if (codeName != null) {
+                    return codeName;
                 }
-                return specVersion.substring(0, specVersion.length()-1);
+                return DetailsUtils.getInstanceFieldString(instance, "data");     // NOI18N
             }
-        } else if (MODULE_DATA.equals(className)) {
-            String name = DetailsUtils.getInstanceFieldString(instance, "codeName");     // NOI18N
-            String version = DetailsUtils.getInstanceFieldString(instance, "specVers");     // NOI18N
-            String implVer = DetailsUtils.getInstanceFieldString(instance, "implVersion");       // NOI18N
-            return String.format("%s [%s %s]", name, version, implVer);
-        } else if (ABSTRACT_NODE.equals(className)) {
-            String name = DetailsUtils.getInstanceFieldString(instance, "displayName"); // NOI18N
+            case DEPENDENCY: {
+                String name = DetailsUtils.getInstanceFieldString(instance, "name");     // NOI18N
+                String version = DetailsUtils.getInstanceFieldString(instance, "version");     // NOI18N
+                int type = DetailsUtils.getIntFieldValue(instance, "type", -1); // NOI18N
+                int comparison = DetailsUtils.getIntFieldValue(instance, "comparison", -1); // NOI18N
+                return DependencyResolver.toString(name, version, type, comparison);
+            }
+            case SPECIFICATION_VERSION: {
+                PrimitiveArrayInstance digits = (PrimitiveArrayInstance) instance.getValueOfField("digits"); // NOI18N
+                if (digits != null) {
+                    StringBuilder specVersion = new StringBuilder();
 
-            if (name == null) {
-                name = DetailsUtils.getInstanceFieldString(instance, "name"); // NOI18N
-            }
-            if (name == null || name.length() == 0) {
-                name = DetailsUtils.getInstanceFieldString(instance, "shortDescription"); // NOI18N
-            }
-            return name;
-        } else if (JAR_FILESYSTEM.equals(className)) {
-            return DetailsUtils.getInstanceFieldString(instance, "foRoot"); // NOI18N
-        } else if (MULTI_FILE_ENTRY.equals(className)) {
-            return DetailsUtils.getInstanceFieldString(instance, "file"); // NOI18N
-        } else if (DATA_OBJECT.equals(className)) {
-            return DetailsUtils.getInstanceFieldString(instance, "primary"); // NOI18N
-        } else if (FILE_OBJ.equals(className)) {
-            return DetailsUtils.getInstanceFieldString(instance, "fileName"); // NOI18N
-        } else if (FOLDER_OBJ.equals(className)) {
-            return DetailsUtils.getInstanceFieldString(instance, "fileName"); // NOI18N
-        } else if (FILE_NAME.equals(className) || FOLDER_NAME.equals(className)
-                || ABSTRACT_FOLDER.equals(className) || BFS_BASE.equals(className)) {
-            String nameString = DetailsUtils.getInstanceFieldString(instance, "name"); // NOI18N
-
-            if (nameString != null) {
-                String parentDetail = DetailsUtils.getInstanceFieldString(instance, "parent"); // NOI18N
-                if (parentDetail != null) {
-                    String sep;
-                    
-                    if (FILE_NAME.equals(className) || FOLDER_NAME.equals(className)) {
-                        // FileObject on the disk - find correct file seperator
-                        Heap heap = instance.getJavaClass().getHeap();
-                        sep = getFileSeparator(heap);
-                        if (parentDetail.endsWith(sep)) {
-                            // do not duplicate separator
-                            sep = "";
-                        }
-                    } else {
-                        sep = "/";
+                    for (Object d : digits.getValues()) {
+                        specVersion.append(d);
+                        specVersion.append('.');
                     }
-                    nameString = parentDetail.concat(sep).concat(nameString);
+                    return specVersion.substring(0, specVersion.length()-1);
                 }
+                break;
             }
-            return nameString;
-        } else if (FIXED_0_7.equals(className)) {
-            Integer i1 = (Integer) instance.getValueOfField("i1"); // NOI18N
-            Integer i2 = (Integer) instance.getValueOfField("i2"); // NOI18N
-            if (i1 != null && i2 != null) {
-                return new Fixed_0_7(i1, i2).toString();
+            case MODULE_DATA: {
+                String name = DetailsUtils.getInstanceFieldString(instance, "codeName");     // NOI18N
+                String version = DetailsUtils.getInstanceFieldString(instance, "specVers");     // NOI18N
+                String implVer = DetailsUtils.getInstanceFieldString(instance, "implVersion");       // NOI18N
+                return String.format("%s [%s %s]", name, version, implVer);
             }
-        } else if (FIXED_8_15.equals(className)) {
-            Integer i1 = (Integer) instance.getValueOfField("i1"); // NOI18N
-            Integer i2 = (Integer) instance.getValueOfField("i2"); // NOI18N
-            Integer i3 = (Integer) instance.getValueOfField("i3"); // NOI18N
-            Integer i4 = (Integer) instance.getValueOfField("i4"); // NOI18N
-            if (i1 != null && i2 != null && i3 != null && i4 != null) {
-                return new Fixed_8_15(i1, i2, i3, i4).toString();
-            }
-        } else if (FIXED_16_23.equals(className)) {
-            Long i1 = (Long) instance.getValueOfField("i1"); // NOI18N
-            Long i2 = (Long) instance.getValueOfField("i2"); // NOI18N
-            Long i3 = (Long) instance.getValueOfField("i3"); // NOI18N
-            if (i1 != null && i2 != null && i3 != null) {
-                return new Fixed_16_23(i1, i2, i3).toString();
-            }
-        } else if (FIXED_1_10.equals(className)) {
-            Long i1 = (Long) instance.getValueOfField("i"); // NOI18N
-            if (i1 != null) {
-                return new Fixed6Bit_1_10(i1).toString();
-            }
-        } else if (FIXED_11_20.equals(className)) {
-            Long i1 = (Long) instance.getValueOfField("i1"); // NOI18N
-            Long i2 = (Long) instance.getValueOfField("i2"); // NOI18N
-            if (i1 != null && i2 != null) {
-                return new Fixed6Bit_11_20(i1, i2).toString();
-            }
-        } else if (FIXED_21_30.equals(className)) {
-            Long i1 = (Long) instance.getValueOfField("i1"); // NOI18N
-            Long i2 = (Long) instance.getValueOfField("i2"); // NOI18N
-            Long i3 = (Long) instance.getValueOfField("i3"); // NOI18N
-            if (i1 != null && i2 != null && i3 != null) {
-                return new Fixed6Bit_21_30(i1, i2, i3).toString();
-            }
-        } else if (BYTE_BASED_SEQUENCE.equals(className)) {
-            Object value = instance.getValueOfField("value");  // NOI18N
-            if (value instanceof PrimitiveArrayInstance) {
-                PrimitiveArrayInstance bytesArr = (PrimitiveArrayInstance) value;
-                byte[] bytes = new byte[bytesArr.getLength()];
-                int i = 0;
+            case ABSTRACT_NODE: {
+                String name = DetailsUtils.getInstanceFieldString(instance, "displayName"); // NOI18N
 
-                for (String b : bytesArr.getValues()) {
-                    bytes[i++] = Byte.valueOf(b);
+                if (name == null) {
+                    name = DetailsUtils.getInstanceFieldString(instance, "name"); // NOI18N
                 }
-                return new String(bytes);
+                if (name == null || name.isEmpty()) {
+                    name = DetailsUtils.getInstanceFieldString(instance, "shortDescription"); // NOI18N
+                }
+                return name;
             }
-        } else if (CHAR_BASED_SEQUENCE.equals(className)) {
-            return DetailsUtils.getInstanceFieldString(instance, "value");    // NOI18N
-        } else if (REQUEST_PROCESSOR.equals(className)) {
-            return DetailsUtils.getInstanceFieldString(instance, "name");     // NOI18N
+            case JAR_FILESYSTEM:
+                return DetailsUtils.getInstanceFieldString(instance, "foRoot"); // NOI18N
+            case MULTI_FILE_ENTRY:
+                return DetailsUtils.getInstanceFieldString(instance, "file"); // NOI18N
+            case DATA_OBJECT:
+                return DetailsUtils.getInstanceFieldString(instance, "primary"); // NOI18N
+            case FILE_OBJ:
+                return DetailsUtils.getInstanceFieldString(instance, "fileName"); // NOI18N
+            case FOLDER_OBJ:
+                return DetailsUtils.getInstanceFieldString(instance, "fileName"); // NOI18N
+            case FILE_NAME:
+            case FOLDER_NAME:
+            case ABSTRACT_FOLDER:
+            case BFS_BASE: {
+                String nameString = DetailsUtils.getInstanceFieldString(instance, "name"); // NOI18N
+
+                if (nameString != null) {
+                    String parentDetail = DetailsUtils.getInstanceFieldString(instance, "parent"); // NOI18N
+                    if (parentDetail != null) {
+                        String sep;
+
+                        if (FILE_NAME.equals(className) || FOLDER_NAME.equals(className)) {
+                            // FileObject on the disk - find correct file seperator
+                            Heap heap = instance.getJavaClass().getHeap();
+                            sep = getFileSeparator(heap);
+                            if (parentDetail.endsWith(sep)) {
+                                // do not duplicate separator
+                                sep = "";
+                            }
+                        } else {
+                            sep = "/";
+                        }
+                        nameString = parentDetail.concat(sep).concat(nameString);
+                    }
+                }
+                return nameString;
+            }
+            case FIXED_0_7: {
+                Integer i1 = (Integer) instance.getValueOfField("i1"); // NOI18N
+                Integer i2 = (Integer) instance.getValueOfField("i2"); // NOI18N
+                if (i1 != null && i2 != null) {
+                    return new Fixed_0_7(i1, i2).toString();
+                }
+                break;
+            }
+            case FIXED_8_15: {
+                Integer i1 = (Integer) instance.getValueOfField("i1"); // NOI18N
+                Integer i2 = (Integer) instance.getValueOfField("i2"); // NOI18N
+                Integer i3 = (Integer) instance.getValueOfField("i3"); // NOI18N
+                Integer i4 = (Integer) instance.getValueOfField("i4"); // NOI18N
+                if (i1 != null && i2 != null && i3 != null && i4 != null) {
+                    return new Fixed_8_15(i1, i2, i3, i4).toString();
+                }
+                break;
+            }
+            case FIXED_16_23: {
+                Long i1 = (Long) instance.getValueOfField("i1"); // NOI18N
+                Long i2 = (Long) instance.getValueOfField("i2"); // NOI18N
+                Long i3 = (Long) instance.getValueOfField("i3"); // NOI18N
+                if (i1 != null && i2 != null && i3 != null) {
+                    return new Fixed_16_23(i1, i2, i3).toString();
+                }
+                break;
+            }
+            case FIXED_1_10:{
+                Long i1 = (Long) instance.getValueOfField("i"); // NOI18N
+                if (i1 != null) {
+                    return new Fixed6Bit_1_10(i1).toString();
+                }
+                break;
+            }
+            case FIXED_11_20:{
+                Long i1 = (Long) instance.getValueOfField("i1"); // NOI18N
+                Long i2 = (Long) instance.getValueOfField("i2"); // NOI18N
+                if (i1 != null && i2 != null) {
+                    return new Fixed6Bit_11_20(i1, i2).toString();
+                }
+                break;
+            }
+            case FIXED_21_30:{
+                Long i1 = (Long) instance.getValueOfField("i1"); // NOI18N
+                Long i2 = (Long) instance.getValueOfField("i2"); // NOI18N
+                Long i3 = (Long) instance.getValueOfField("i3"); // NOI18N
+                if (i1 != null && i2 != null && i3 != null) {
+                    return new Fixed6Bit_21_30(i1, i2, i3).toString();
+                }
+                break;
+            }
+            case BYTE_BASED_SEQUENCE: {
+                Object value = instance.getValueOfField("value");  // NOI18N
+                if (value instanceof PrimitiveArrayInstance) {
+                    PrimitiveArrayInstance bytesArr = (PrimitiveArrayInstance) value;
+                    byte[] bytes = new byte[bytesArr.getLength()];
+                    int i = 0;
+
+                    for (String b : bytesArr.getValues()) {
+                        bytes[i++] = Byte.valueOf(b);
+                    }
+                    return new String(bytes);
+                }
+                break;
+            }
+            case CHAR_BASED_SEQUENCE:
+                return DetailsUtils.getInstanceFieldString(instance, "value");    // NOI18N
+            case REQUEST_PROCESSOR:
+                return DetailsUtils.getInstanceFieldString(instance, "name");     // NOI18N
+            default:
+                break;
         }
         return null;
     }
@@ -1609,7 +1618,7 @@ public class PlatformDetailsProvider extends DetailsProvider.Basic {
             throw new UnsupportedOperationException("Not supported yet."); //To change body of generated methods, choose Tools | Templates.
         }
 
-        public CharSequences() {
+        CharSequences() {
         }
     }
 
