@@ -1,43 +1,26 @@
 /*
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
+ * Copyright (c) 2010, 2021, Oracle and/or its affiliates. All rights reserved.
+ * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
- * Copyright 2010 Oracle and/or its affiliates. All rights reserved.
- *
- * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
- * Other names may be trademarks of their respective owners.
- *
- * The contents of this file are subject to the terms of either the GNU
- * General Public License Version 2 only ("GPL") or the Common
- * Development and Distribution License("CDDL") (collectively, the
- * "License"). You may not use this file except in compliance with the
- * License. You can obtain a copy of the License at
- * http://www.netbeans.org/cddl-gplv2.html
- * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
- * specific language governing permissions and limitations under the
- * License.  When distributing the software, include this License Header
- * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
+ * This code is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License version 2 only, as
+ * published by the Free Software Foundation.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Oracle in the GPL Version 2 section of the License file that
- * accompanied this code. If applicable, add the following below the
- * License Header, with the fields enclosed by brackets [] replaced by
- * your own identifying information:
- * "Portions Copyrighted [year] [name of copyright owner]"
+ * by Oracle in the LICENSE file that accompanied this code.
  *
- * If you wish your version of this file to be governed by only the CDDL
- * or only the GPL Version 2, indicate your decision by adding
- * "[Contributor] elects to include this software in this distribution
- * under the [CDDL or GPL Version 2] license." If you do not indicate a
- * single choice of license, a recipient has the option to distribute
- * your version of this file under either the CDDL, the GPL Version 2 or
- * to extend the choice of license to its licensees as provided above.
- * However, if you add GPL Version 2 code and therefore, elected the GPL
- * Version 2 license, then the option applies only if the new code is
- * made subject to such option by the copyright holder.
+ * This code is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * version 2 for more details (a copy is included in the LICENSE file that
+ * accompanied this code).
  *
- * Contributor(s):
+ * You should have received a copy of the GNU General Public License version
+ * 2 along with this work; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
  *
- * Portions Copyrighted 2008 Sun Microsystems, Inc.
+ * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
+ * or visit www.oracle.com if you need additional information or have any
+ * questions.
  */
 package org.graalvm.visualvm.lib.profiler.oql.engine.api.impl;
 
@@ -57,8 +40,6 @@ import org.graalvm.visualvm.lib.jfluid.heap.PrimitiveArrayInstance;
 import org.graalvm.visualvm.lib.jfluid.heap.Value;
 import org.graalvm.visualvm.lib.profiler.oql.engine.api.OQLEngine;
 import org.graalvm.visualvm.lib.profiler.oql.engine.api.ReferenceChain;
-
-import static org.graalvm.visualvm.lib.jfluid.utils.VMUtils.*;
 import org.openide.util.Enumerations;
 
 /**
@@ -70,12 +51,24 @@ import org.openide.util.Enumerations;
  * heapwalker model
  */
 public class Snapshot {
+
+    private static final String BOOLEAN_CODE = "Z"; // NOI18N
+    private static final String CHAR_CODE = "C"; // NOI18N
+    private static final String BYTE_CODE = "B"; // NOI18N
+    private static final String SHORT_CODE = "S"; // NOI18N
+    private static final String INT_CODE = "I"; // NOI18N
+    private static final String LONG_CODE = "J"; // NOI18N
+    private static final String FLOAT_CODE = "F"; // NOI18N
+    private static final String DOUBLE_CODE = "D"; // NOI18N
+    private static final String VOID_CODE = "V"; // NOI18N
+    private static final char REFERENCE = 'L'; // NOI18N
+
     private final Heap delegate;
     private JavaClass weakReferenceClass;
     private int referentFieldIndex;
     private ReachableExcludes reachableExcludes;
     final private OQLEngine engine;
-    
+
     public Snapshot(Heap heap, OQLEngine engine) {
         this.delegate = heap;
         this.engine = engine;
@@ -122,21 +115,21 @@ public class Snapshot {
         }
         if (className.length() == 1) {
             if (className.equals(INT_CODE)) {
-                className = INT_STRING;
+                className = int.class.toString();
             } else if (className.equals(LONG_CODE)) {
-                className = LONG_STRING;
+                className = long.class.toString();
             } else if (className.equals(DOUBLE_CODE)) {
-                className = DOUBLE_STRING;
+                className = double.class.toString();
             } else if (className.equals(FLOAT_CODE)) {
-                className = FLOAT_STRING;
+                className = float.class.toString();
             } else if (className.equals(BYTE_CODE)) {
-                className = BYTE_STRING;
+                className = byte.class.toString();
             } else if (className.equals(SHORT_CODE)) {
-                className = SHORT_STRING;
+                className = short.class.toString();
             } else if (className.equals(CHAR_CODE)) {
-                className = CHAR_STRING;
+                className = char.class.toString();
             } else if (className.equals(BOOLEAN_CODE)) {
-                className = BOOLEAN_STRING;
+                className = boolean.class.toString();
             }
         }
         if (arrDim > 0 && className.charAt(0) == REFERENCE) {   // class name
@@ -182,27 +175,27 @@ public class Snapshot {
         return distance;
     }
 
-    public Enumeration concat(Enumeration en1, Enumeration en2) {
+    public <T> Enumeration<T> concat(Enumeration<? extends T> en1, Enumeration<? extends T> en2) {
         return Enumerations.concat(en1, en2);
     }
 
     /**
      * Return an Iterator of all of the classes in this snapshot.
      **/
-    public Iterator getClasses() {
+    public Iterator<JavaClass> getClasses() {
         return delegate.getAllClasses().iterator();
     }
 
-    public Iterator getClassNames(String regex)  {
-        final Iterator delegated = delegate.getJavaClassesByRegExp(regex).iterator();
-        return new Iterator() {
+    public Iterator<String> getClassNames(String regex)  {
+        final Iterator<JavaClass> delegated = delegate.getJavaClassesByRegExp(regex).iterator();
+        return new Iterator<String>() {
 
             public boolean hasNext() {
                 return delegated.hasNext();
             }
 
-            public Object next() {
-                return ((JavaClass)delegated.next()).getName();
+            public String next() {
+                return delegated.next().getName();
             }
 
             public void remove() {
@@ -212,7 +205,7 @@ public class Snapshot {
 
     }
 
-    public Iterator getInstances(final JavaClass clazz, final boolean includeSubclasses) {
+    public Iterator<Instance> getInstances(final JavaClass clazz, final boolean includeSubclasses) {
         // special case for all subclasses of java.lang.Object
         if (includeSubclasses && clazz.getSuperClass() == null) {
             return delegate.getAllInstancesIterator();
@@ -226,14 +219,14 @@ public class Snapshot {
 
             @Override
             protected Iterator<JavaClass> getTraversingIterator(JavaClass popped) {
-                return includeSubclasses ? popped.getSubClasses().iterator() : Collections.EMPTY_LIST.iterator();
+                return includeSubclasses ? popped.getSubClasses().iterator() : Collections.emptyIterator();
             }
         };
     }
 
-    public Iterator getReferrers(Object obj, boolean includeWeak) {
-        List instances = new ArrayList();
-        List references = new ArrayList();
+    public Iterator<Object> getReferrers(Object obj, boolean includeWeak) {
+        List<Object> instances = new ArrayList<>();
+        List<Object> references = new ArrayList<>();
         
         if (obj instanceof Instance) {
             references.addAll(((Instance)obj).getReferences());
@@ -259,9 +252,9 @@ public class Snapshot {
         return instances.iterator();
     }
 
-    public Iterator getReferees(Object obj, boolean includeWeak) {
-        List instances = new ArrayList();
-        List values = new ArrayList();
+    public Iterator<Object> getReferees(Object obj, boolean includeWeak) {
+        List<Object> instances = new ArrayList<>();
+        List<Object> values = new ArrayList<>();
         
         if (obj instanceof Instance) {
             Instance o = (Instance)obj;
@@ -300,12 +293,12 @@ public class Snapshot {
         return instances.iterator();
     }
 
-    public Iterator getFinalizerObjects() {
+    public Iterator<Instance> getFinalizerObjects() {
         JavaClass clazz = findClass("java.lang.ref.Finalizer"); // NOI18N
         Instance queue = (Instance) clazz.getValueOfStaticField("queue"); // NOI18N
         Instance head = (Instance) queue.getValueOfField("head"); // NOI18N
 
-        List finalizables = new ArrayList();
+        List<Instance> finalizables = new ArrayList<>();
         if (head != null) {
             while (true) {
                 Instance referent = (Instance) head.getValueOfField("referent"); // NOI18N
@@ -321,12 +314,12 @@ public class Snapshot {
         return finalizables.iterator();
     }
 
-    public Iterator getRoots() {
+    public Iterator<GCRoot> getRoots() {
         return delegate.getGCRoots().iterator();
     }
     
-    private Set getRootsInstances() {
-        Set<Object> roots = new HashSet<Object>();
+    private Set<Object> getRootsInstances() {
+        Set<Object> roots = new HashSet<>();
         for(GCRoot root : delegate.getGCRoots()) {
             Instance inst = root.getInstance();
             if (inst.getJavaClass().getName().equals("java.lang.Class")) {
@@ -350,21 +343,21 @@ public class Snapshot {
    
     public ReferenceChain[] rootsetReferencesTo(Instance target, boolean includeWeak) {
         class State {
-            private Iterator<Instance> iterator;
+            private Iterator<Object> iterator;
             private ReferenceChain path;
             private AtomicLong hits = new AtomicLong(0);
 
-            public State(ReferenceChain path, Iterator<Instance> iterator) {
+            State(ReferenceChain path, Iterator<Object> iterator) {
                 this.iterator = iterator;
                 this.path = path;
             }
         }
-        Deque<State> stack = new ArrayDeque<State>();
-        Set ignored = new HashSet();
+        Deque<State> stack = new ArrayDeque<>();
+        Set<Object> ignored = new HashSet<>();
         
-        List<ReferenceChain> result = new ArrayList<ReferenceChain>();
+        List<ReferenceChain> result = new ArrayList<>();
         
-        Iterator toInspect = getRootsInstances().iterator();
+        Iterator<Object> toInspect = getRootsInstances().iterator();
         ReferenceChain path = null;
         State s = new State(path, toInspect);
         
@@ -437,7 +430,7 @@ public class Snapshot {
         if (instance == null) return null;
         try {
             if (instance.getJavaClass().getName().equals(String.class.getName())) {
-                Class proxy = Class.forName("org.graalvm.visualvm.lib.jfluid.heap.HprofProxy"); // NOI18N
+                Class<?> proxy = Class.forName("org.graalvm.visualvm.lib.jfluid.heap.HprofProxy"); // NOI18N
                 Method method = proxy.getDeclaredMethod("getString", Instance.class); // NOI18N
                 method.setAccessible(true);
                 return (String) method.invoke(proxy, instance);
