@@ -1,44 +1,26 @@
 /*
- * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
+ * Copyright (c) 1997, 2021, Oracle and/or its affiliates. All rights reserved.
+ * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
- * Copyright 1997-2010 Oracle and/or its affiliates. All rights reserved.
- *
- * Oracle and Java are registered trademarks of Oracle and/or its affiliates.
- * Other names may be trademarks of their respective owners.
- *
- * The contents of this file are subject to the terms of either the GNU
- * General Public License Version 2 only ("GPL") or the Common
- * Development and Distribution License("CDDL") (collectively, the
- * "License"). You may not use this file except in compliance with the
- * License. You can obtain a copy of the License at
- * http://www.netbeans.org/cddl-gplv2.html
- * or nbbuild/licenses/CDDL-GPL-2-CP. See the License for the
- * specific language governing permissions and limitations under the
- * License.  When distributing the software, include this License Header
- * Notice in each file and include the License file at
- * nbbuild/licenses/CDDL-GPL-2-CP.  Oracle designates this
+ * This code is free software; you can redistribute it and/or modify it
+ * under the terms of the GNU General Public License version 2 only, as
+ * published by the Free Software Foundation.  Oracle designates this
  * particular file as subject to the "Classpath" exception as provided
- * by Oracle in the GPL Version 2 section of the License file that
- * accompanied this code. If applicable, add the following below the
- * License Header, with the fields enclosed by brackets [] replaced by
- * your own identifying information:
- * "Portions Copyrighted [year] [name of copyright owner]"
+ * by Oracle in the LICENSE file that accompanied this code.
  *
- * Contributor(s):
- * The Original Software is NetBeans. The Initial Developer of the Original
- * Software is Sun Microsystems, Inc. Portions Copyright 1997-2006 Sun
- * Microsystems, Inc. All Rights Reserved.
+ * This code is distributed in the hope that it will be useful, but WITHOUT
+ * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
+ * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
+ * version 2 for more details (a copy is included in the LICENSE file that
+ * accompanied this code).
  *
- * If you wish your version of this file to be governed by only the CDDL
- * or only the GPL Version 2, indicate your decision by adding
- * "[Contributor] elects to include this software in this distribution
- * under the [CDDL or GPL Version 2] license." If you do not indicate a
- * single choice of license, a recipient has the option to distribute
- * your version of this file under either the CDDL, the GPL Version 2 or
- * to extend the choice of license to its licensees as provided above.
- * However, if you add GPL Version 2 code and therefore, elected the GPL
- * Version 2 license, then the option applies only if the new code is
- * made subject to such option by the copyright holder.
+ * You should have received a copy of the GNU General Public License version
+ * 2 along with this work; if not, write to the Free Software Foundation,
+ * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
+ *
+ * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
+ * or visit www.oracle.com if you need additional information or have any
+ * questions.
  */
 
 package org.graalvm.visualvm.lib.profiler;
@@ -185,10 +167,10 @@ public final class ResultsManager {
 
     //~ Instance fields ----------------------------------------------------------------------------------------------------------
 
-    private ArrayList<LoadedSnapshot> loadedSnapshots = new ArrayList<LoadedSnapshot>();
+    private ArrayList<LoadedSnapshot> loadedSnapshots = new ArrayList<>();
     private File exportDir;
-    private HashMap<FileObject, ProfilingSettings> settingsCache = new HashMap<FileObject, ProfilingSettings>();
-    private HashMap<FileObject, Integer> typeCache = new HashMap<FileObject, Integer>();
+    private HashMap<FileObject, ProfilingSettings> settingsCache = new HashMap<>();
+    private HashMap<FileObject, Integer> typeCache = new HashMap<>();
     private Window mainWindow;
     private boolean resultsAvailable = false;
     
@@ -577,8 +559,8 @@ public final class ResultsManager {
             @Override
             public void run() {
                 try {
-                    for (int i = 0; i < selectedSnapshots.length; i++) {
-                        exportSnapshot(selectedSnapshots[i], dir[0], fileName[0] != null ? fileName[0] : selectedSnapshots[i].getName(), fileExt[0] != null ? fileExt[0] : selectedSnapshots[i].getExt());
+                    for (FileObject selectedSnapshot : selectedSnapshots) {
+                        exportSnapshot(selectedSnapshot, dir[0], fileName[0] != null ? fileName[0] : selectedSnapshot.getName(), fileExt[0] != null ? fileExt[0] : selectedSnapshot.getExt());
                     }
                 } finally {
                     ph.finish();
@@ -588,11 +570,7 @@ public final class ResultsManager {
     }
 
     public LoadedSnapshot findLoadedSnapshot(ResultsSnapshot snapshot) {
-        Iterator it = loadedSnapshots.iterator();
-
-        while (it.hasNext()) {
-            LoadedSnapshot ls = (LoadedSnapshot) it.next();
-
+        for (LoadedSnapshot ls : loadedSnapshots) {
             if (ls.getSnapshot() == snapshot) {
                 return ls;
             }
@@ -602,11 +580,7 @@ public final class ResultsManager {
     }
 
     public LoadedSnapshot findLoadedSnapshot(File snapshotFile) {
-        Iterator it = loadedSnapshots.iterator();
-
-        while (it.hasNext()) {
-            LoadedSnapshot ls = (LoadedSnapshot) it.next();
-
+        for (LoadedSnapshot ls : loadedSnapshots) {
             if ((ls.getFile() != null) && ls.getFile().equals(snapshotFile)) {
                 return ls;
             }
@@ -621,9 +595,9 @@ public final class ResultsManager {
         try {
             if (file.isFile() && file.canRead() && file.length()>MIN_HPROF_SIZE) { // heap dump must be 1M and bigger
                 byte[] prefix = new byte[HPROF_HEADER.length()+4];
-                RandomAccessFile raf = new RandomAccessFile(file,"r");  // NOI18H
-                raf.readFully(prefix);
-                raf.close();
+                try (RandomAccessFile raf = new RandomAccessFile(file,"r")) {   // NOI18N
+                    raf.readFully(prefix);
+                }
                 if (new String(prefix).startsWith(HPROF_HEADER)) {
                     return true;
                 }
@@ -656,10 +630,10 @@ public final class ResultsManager {
 
             ArrayList /*<FileObject>*/ files = new ArrayList /*<FileObject>*/();
 
-            for (int i = 0; i < children.length; i++) {
-                FileObject child = children[i];
-                if (checkHprofFile(FileUtil.toFile(children[i])))
+            for (FileObject child : children) {
+                if (checkHprofFile(FileUtil.toFile(child))) {
                     files.add(child);
+                }
             }
 
             Collections.sort(files,
@@ -700,9 +674,7 @@ public final class ResultsManager {
 
             ArrayList /*<FileObject>*/ files = new ArrayList /*<FileObject>*/();
 
-            for (int i = 0; i < children.length; i++) {
-                FileObject child = children[i];
-
+            for (FileObject child : children) {
                 if (child.getExt().equalsIgnoreCase(SNAPSHOT_EXTENSION)) {
                     files.add(child);
                 }
@@ -834,10 +806,9 @@ public final class ResultsManager {
         try {
             SnapshotResultsWindow srw = null;
 
-            for (int i = 0; i < loaded.length; i++) {
-                loadedSnapshot = loaded[i];
-
-                if (loaded[i] != null) {
+            for (LoadedSnapshot loaded1 : loaded) {
+                loadedSnapshot = loaded1;
+                if (loaded1 != null) {
                     srw = SnapshotResultsWindow.get(loadedSnapshot);
                     srw.open();
                 }
@@ -1457,16 +1428,12 @@ public final class ResultsManager {
             ProfilingSettings settings = new ProfilingSettings();
             ByteArrayInputStream bais2 = new ByteArrayInputStream(settingsBytes);
             BufferedInputStream bufBais2 = new BufferedInputStream(bais2);
-            DataInputStream settingsDis = new DataInputStream(bufBais2);
-
-            try {
+            try (DataInputStream settingsDis = new DataInputStream(bufBais2)) {
                 props.load(settingsDis);
             } catch (IOException e) {
                 ProfilerLogger.log(e);
 
                 return null;
-            } finally {
-                settingsDis.close();
             }
 
             settings.load(props);
