@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -25,9 +25,15 @@
 
 package org.graalvm.visualvm.profiler;
 
+import java.io.File;
+import java.util.ArrayList;
+import java.util.List;
+import java.util.Properties;
+import javax.swing.SwingUtilities;
 import org.graalvm.visualvm.application.Application;
 import org.graalvm.visualvm.application.jvm.Jvm;
 import org.graalvm.visualvm.application.jvm.JvmFactory;
+import org.graalvm.visualvm.core.VisualVM;
 import org.graalvm.visualvm.core.datasource.descriptor.DataSourceDescriptor;
 import org.graalvm.visualvm.core.datasource.descriptor.DataSourceDescriptorFactory;
 import org.graalvm.visualvm.core.datasupport.DataChangeEvent;
@@ -36,19 +42,13 @@ import org.graalvm.visualvm.core.datasupport.Stateful;
 import org.graalvm.visualvm.core.ui.DataSourceView;
 import org.graalvm.visualvm.core.ui.DataSourceWindowManager;
 import org.graalvm.visualvm.host.Host;
-import org.graalvm.visualvm.profiling.presets.ProfilerPreset;
-import java.io.File;
-import java.util.ArrayList;
-import java.util.List;
-import java.util.Properties;
-import javax.swing.SwingUtilities;
-import org.graalvm.visualvm.core.VisualVM;
 import org.graalvm.visualvm.lib.common.Profiler;
 import org.graalvm.visualvm.lib.common.ProfilingSettings;
 import org.graalvm.visualvm.lib.common.SessionSettings;
 import org.graalvm.visualvm.lib.jfluid.global.Platform;
 import org.graalvm.visualvm.lib.profiler.NetBeansProfiler;
 import org.graalvm.visualvm.lib.profiler.api.ProfilerIDESettings;
+import org.graalvm.visualvm.profiling.presets.ProfilerPreset;
 import org.openide.DialogDisplayer;
 import org.openide.NotifyDescriptor;
 import org.openide.util.NbBundle;
@@ -102,32 +102,13 @@ public final class ProfilerSupport {
     }
     
     public boolean hasSupportedJavaPlatforms() {
-        // jdk 1.5 .. 1.9
-        for (int i = 5; i <= 9; i++) {
-            String code = "jdk1" + i; // NOI18N
-            if (supportsProfiling(code, 32) || supportsProfiling(code, 64)) return true;
-        }
-        // jdk 10 .. jdk 16
-        for (int i = 10; i <= 16; i++) {
-            String code = "jdk" + i + "0"; // NOI18N
-            if (supportsProfiling(code, 32) || supportsProfiling(code, 64)) return true;
-        }
-        return false;
+        List<String> codesl = getSupprtedJavaPlatformIds();
+
+        return !codesl.isEmpty();
     }
     
     public String[][] getSupportedJavaPlatforms() {
-        List<String> codesl = new ArrayList();
-        
-        // jdk 1.5 .. 1.9
-        for (int i = 5; i <= 9; i++) {
-            String code = "jdk1" + i; // NOI18N
-            if (supportsProfiling(code, 32) || supportsProfiling(code, 64)) codesl.add(code);
-        }
-        // jdk 10 .. jdk 16
-        for (int i = 10; i <= 16; i++) {
-            String code = "jdk" + i +"0"; // NOI18N
-            if (supportsProfiling(code, 32) || supportsProfiling(code, 64)) codesl.add(code);
-        }
+        List<String> codesl = getSupprtedJavaPlatformIds();
         
         String[] names = new String[codesl.size()];
         String[] codes = new String[codesl.size()];
@@ -142,7 +123,7 @@ public final class ProfilerSupport {
     }
     
     public String[][] getSupportedArchitectures(String java) {
-        List<String> codesl = new ArrayList();
+        List<String> codesl = new ArrayList<>();
         
         if (supportsProfiling(java, 32)) codesl.add(Integer.toString(32));
         if (supportsProfiling(java, 64)) codesl.add(Integer.toString(64));
@@ -184,6 +165,12 @@ public final class ProfilerSupport {
             return NbBundle.getMessage(ProfilerSupport.class, "STR_Java_platform_name", 15); // NOI18N
         if (Platform.JDK_160_STRING.equals(code))
             return NbBundle.getMessage(ProfilerSupport.class, "STR_Java_platform_name", 16); // NOI18N
+        if (Platform.JDK_170_STRING.equals(code))
+            return NbBundle.getMessage(ProfilerSupport.class, "STR_Java_platform_name", 17); // NOI18N
+        if (Platform.JDK_180_STRING.equals(code))
+            return NbBundle.getMessage(ProfilerSupport.class, "STR_Java_platform_name", 18); // NOI18N
+        if (Platform.JDK_190_STRING.equals(code))
+            return NbBundle.getMessage(ProfilerSupport.class, "STR_Java_platform_name", 19); // NOI18N
         throw new IllegalArgumentException("Unknown java code " + code); // NOI18N
     }
     
@@ -227,7 +214,7 @@ public final class ProfilerSupport {
                 Host.LOCALHOST.getRepository().addDataChangeListener(
                     new DataChangeListener<Application>() {
                         public void dataChanged(final DataChangeEvent<Application> event) {
-                            final DataChangeListener listener = this;
+                            final DataChangeListener<Application> listener = this;
                             processor.post(new Runnable() {
                                 public void run() {
                                     if (!event.getAdded().equals(event.getCurrent())) // filter-out initial sync event
@@ -375,11 +362,11 @@ public final class ProfilerSupport {
     }
     
     private static int getUpdateNumber(String javaRTVersion) {
-        int underscoreIndex = javaRTVersion.indexOf("_"); // NOI18N
+        int underscoreIndex = javaRTVersion.indexOf('_'); // NOI18N
         if (underscoreIndex == -1) return 0; // Assumes no update, may be incorrect for unexpected javaRTVersion format
         
         try {
-            String updateNumberString = javaRTVersion.substring(underscoreIndex + "_".length(), javaRTVersion.indexOf("-")); // NOI18N
+            String updateNumberString = javaRTVersion.substring(underscoreIndex + "_".length(), javaRTVersion.indexOf('-')); // NOI18N
             return Integer.parseInt(updateNumberString);
         } catch (Exception e) {}
         
@@ -398,7 +385,7 @@ public final class ProfilerSupport {
     private static int getJVMArchitecture(Jvm jvm) {
         Properties sysprops = jvm.getSystemProperties();
         String jvmArch = sysprops == null ? null : sysprops.getProperty("sun.arch.data.model");    // NOI18N
-        return jvmArch == null ? -1 : Integer.valueOf(jvmArch);
+        return jvmArch == null ? -1 : Integer.parseInt(jvmArch);
     }
     
     synchronized void setProfiledApplication(Application profiledApplication) {
@@ -432,6 +419,20 @@ public final class ProfilerSupport {
         });
     }
     
+    private List<String> getSupprtedJavaPlatformIds() {
+        List<String> codesl = new ArrayList<>();
+        // jdk 1.5 .. 1.9
+        for (int i = 5; i <= 9; i++) {
+            String code = "jdk1" + i; // NOI18N
+            if (supportsProfiling(code, 32) || supportsProfiling(code, 64)) codesl.add(code);
+        }
+        // jdk 10 .. jdk 19
+        for (int i = 10; i <= 19; i++) {
+            String code = "jdk" + i +"0"; // NOI18N
+            if (supportsProfiling(code, 32) || supportsProfiling(code, 64)) codesl.add(code);
+        }
+        return codesl;
+    }
     
     private ProfilerSupport() {
         isInitialized = NetBeansProfiler.isInitialized();
