@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2007, 2011, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2007, 2021, Oracle and/or its affiliates. All rights reserved.
  * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
  *
  * This code is free software; you can redistribute it and/or modify it
@@ -25,9 +25,6 @@
 
 package org.graalvm.visualvm.tools.jvmstat;
 
-import org.graalvm.visualvm.application.Application;
-import org.graalvm.visualvm.core.model.Model;
-import org.graalvm.visualvm.host.Host;
 import java.io.File;
 import java.io.IOException;
 import java.util.List;
@@ -35,6 +32,8 @@ import java.util.jar.Attributes;
 import java.util.jar.JarFile;
 import java.util.logging.Logger;
 import java.util.regex.Pattern;
+import org.graalvm.visualvm.application.Application;
+import org.graalvm.visualvm.core.model.Model;
 import org.openide.util.NbBundle;
 
 /**
@@ -229,11 +228,14 @@ public abstract class JvmJvmstatModel extends Model {
 
     public String getMainArgs() {
         String commandLine = getCommandLine();
-        String arg0 = getFirstArgument();
 
-        int firstSpace = arg0.length();
-        if (firstSpace < commandLine.length()) {
-            return commandLine.substring(firstSpace);
+        if (commandLine != null) {
+            String arg0 = getFirstArgument();
+
+            int firstSpace = arg0.length();
+            if (firstSpace < commandLine.length()) {
+                return commandLine.substring(firstSpace);
+            }
         }
         return null;
     }
@@ -249,15 +251,15 @@ public abstract class JvmJvmstatModel extends Model {
      */
     public String getMainClass() {
         String mainClassName = getFirstArgument();
+
+        if (mainClassName == null) return null;
         // if we are on localhost try read main class from jar file
-        if (application.getHost().equals(Host.LOCALHOST)) {
+        if (application.isLocalApplication()) {
             File jarFile = new File(mainClassName);
             if (jarFile.exists()) {
-                try {
-                    JarFile jf = new JarFile(jarFile);
+                try (JarFile jf = new JarFile(jarFile)) {
                     mainClassName = jf.getManifest().getMainAttributes().getValue(Attributes.Name.MAIN_CLASS);
                     assert mainClassName!=null;
-                    jf.close();
                 } catch (IOException ex) {
                     LOGGER.throwing(JvmJvmstatModel.class.getName(), "getMainClass", ex);   // NOI18N
                 }
@@ -281,6 +283,7 @@ public abstract class JvmJvmstatModel extends Model {
         String commandLine = getCommandLine();
         String mainClassName = null;
         
+        if (commandLine == null) return mainClassName;
         // search for jar file
         int jarIndex = commandLine.indexOf(JAR_SUFFIX); 
         if (jarIndex != -1) {
@@ -289,7 +292,7 @@ public abstract class JvmJvmstatModel extends Model {
             if (jarFile.length() == commandLine.length() || commandLine.charAt(jarFile.length()) == ' ') {
                 // jarFile must be on classpath
                 String classPath = getClassPath();
-                if (classPath != null && classPath.indexOf(jarFile) != -1) {
+                if (classPath != null && classPath.contains(jarFile)) {
                     mainClassName = jarFile;
                 }
             }
